use Test::More;
use Lingua::EN::Inflexion;

ok noun(q{metalimnion})->is_singular  => q{is_singular: 'metalimnion'};
ok noun(q{cladus})->is_singular  => q{is_singular: 'cladus'};
ok noun(q{pro})->is_singular  => q{is_singular: 'pro'};
ok noun(q{herself})->is_singular  => q{is_singular: 'herself'};
ok noun(q{microfiche})->is_singular  => q{is_singular: 'microfiche'};
ok noun(q{glasses})->is_singular  => q{is_singular: 'glasses'};
ok noun(q{impetus})->is_singular  => q{is_singular: 'impetus'};
ok noun(q{proscolla})->is_singular  => q{is_singular: 'proscolla'};
ok noun(q{modus})->is_singular  => q{is_singular: 'modus'};
ok noun(q{vorstellung})->is_singular  => q{is_singular: 'vorstellung'};
ok noun(q{womanchild})->is_singular  => q{is_singular: 'womanchild'};
ok noun(q{thema})->is_singular  => q{is_singular: 'thema'};
ok noun(q{hairdo})->is_singular  => q{is_singular: 'hairdo'};
ok noun(q{trattoria})->is_singular  => q{is_singular: 'trattoria'};
ok noun(q{mycoplasma})->is_singular  => q{is_singular: 'mycoplasma'};
ok noun(q{Lilo})->is_singular  => q{is_singular: 'Lilo'};
ok noun(q{lumbago})->is_singular  => q{is_singular: 'lumbago'};
ok noun(q{craspedon})->is_singular  => q{is_singular: 'craspedon'};
ok noun(q{pes})->is_singular  => q{is_singular: 'pes'};
ok noun(q{miles gloriosus})->is_singular  => q{is_singular: 'miles gloriosus'};
ok noun(q{pycnium})->is_singular  => q{is_singular: 'pycnium'};
ok noun(q{pycnidium})->is_singular  => q{is_singular: 'pycnidium'};
ok noun(q{syntaxis})->is_singular  => q{is_singular: 'syntaxis'};
ok noun(q{crazia})->is_singular  => q{is_singular: 'crazia'};
ok noun(q{modelletto})->is_singular  => q{is_singular: 'modelletto'};
ok noun(q{pleurum})->is_singular  => q{is_singular: 'pleurum'};
ok noun(q{Harlemese})->is_singular  => q{is_singular: 'Harlemese'};
ok noun(q{tong})->is_singular  => q{is_singular: 'tong'};
ok noun(q{oratrix})->is_singular  => q{is_singular: 'oratrix'};
ok noun(q{foramen})->is_singular  => q{is_singular: 'foramen'};
ok noun(q{blues})->is_singular  => q{is_singular: 'blues'};
ok noun(q{lieu})->is_singular  => q{is_singular: 'lieu'};
ok noun(q{logion})->is_singular  => q{is_singular: 'logion'};
ok noun(q{pence})->is_singular  => q{is_singular: 'pence'};
ok noun(q{agape})->is_singular  => q{is_singular: 'agape'};
ok noun(q{cannabis})->is_singular  => q{is_singular: 'cannabis'};
ok noun(q{calzone})->is_singular  => q{is_singular: 'calzone'};
ok noun(q{cheval-de-bataille})->is_singular  => q{is_singular: 'cheval-de-bataille'};
ok noun(q{pycnis})->is_singular  => q{is_singular: 'pycnis'};
ok noun(q{lacuna})->is_singular  => q{is_singular: 'lacuna'};
ok noun(q{moose})->is_singular  => q{is_singular: 'moose'};
ok noun(q{junto})->is_singular  => q{is_singular: 'junto'};
ok noun(q{court martial})->is_singular  => q{is_singular: 'court martial'};
ok noun(q{costa})->is_singular  => q{is_singular: 'costa'};
ok noun(q{Borghese})->is_singular  => q{is_singular: 'Borghese'};
ok noun(q{Zibo})->is_singular  => q{is_singular: 'Zibo'};
ok noun(q{hake})->is_singular  => q{is_singular: 'hake'};
ok noun(q{calix})->is_singular  => q{is_singular: 'calix'};
ok noun(q{dace})->is_singular  => q{is_singular: 'dace'};
ok noun(q{thalamus})->is_singular  => q{is_singular: 'thalamus'};
ok noun(q{oceanarium})->is_singular  => q{is_singular: 'oceanarium'};
ok noun(q{ichthyosaurus})->is_singular  => q{is_singular: 'ichthyosaurus'};
ok noun(q{its})->is_singular  => q{is_singular: 'its'};
ok noun(q{sensoriolum})->is_singular  => q{is_singular: 'sensoriolum'};
ok noun(q{scholium})->is_singular  => q{is_singular: 'scholium'};
ok noun(q{pliers})->is_singular  => q{is_singular: 'pliers'};
ok noun(q{curriculum})->is_singular  => q{is_singular: 'curriculum'};
ok noun(q{kylix})->is_singular  => q{is_singular: 'kylix'};
ok noun(q{tumulus})->is_singular  => q{is_singular: 'tumulus'};
ok noun(q{matzah})->is_singular  => q{is_singular: 'matzah'};
ok noun(q{knife})->is_singular  => q{is_singular: 'knife'};
ok noun(q{yes})->is_singular  => q{is_singular: 'yes'};
ok noun(q{curioso})->is_singular  => q{is_singular: 'curioso'};
ok noun(q{pimento})->is_singular  => q{is_singular: 'pimento'};
ok noun(q{craspedum})->is_singular  => q{is_singular: 'craspedum'};
ok noun(q{squalus})->is_singular  => q{is_singular: 'squalus'};
ok noun(q{toxicum})->is_singular  => q{is_singular: 'toxicum'};
ok noun(q{chou})->is_singular  => q{is_singular: 'chou'};
ok noun(q{silbador})->is_singular  => q{is_singular: 'silbador'};
ok noun(q{exencephalus})->is_singular  => q{is_singular: 'exencephalus'};
ok noun(q{bandeau})->is_singular  => q{is_singular: 'bandeau'};
ok noun(q{pernio})->is_singular  => q{is_singular: 'pernio'};
ok noun(q{tempo})->is_singular  => q{is_singular: 'tempo'};
ok noun(q{rond de jambe})->is_singular  => q{is_singular: 'rond de jambe'};
ok noun(q{nomisma})->is_singular  => q{is_singular: 'nomisma'};
ok noun(q{Paramaribo})->is_singular  => q{is_singular: 'Paramaribo'};
ok noun(q{sum-total})->is_singular  => q{is_singular: 'sum-total'};
ok noun(q{graffiti})->is_singular  => q{is_singular: 'graffiti'};
ok noun(q{naya paisa})->is_singular  => q{is_singular: 'naya paisa'};
ok noun(q{Silurus})->is_singular  => q{is_singular: 'Silurus'};
ok noun(q{fly})->is_singular  => q{is_singular: 'fly'};
ok noun(q{Yuman})->is_singular  => q{is_singular: 'Yuman'};
ok noun(q{toril})->is_singular  => q{is_singular: 'toril'};
ok noun(q{tenderfoot})->is_singular  => q{is_singular: 'tenderfoot'};
ok noun(q{paraganglion})->is_singular  => q{is_singular: 'paraganglion'};
ok noun(q{solarium})->is_singular  => q{is_singular: 'solarium'};
ok noun(q{mesothelioma})->is_singular  => q{is_singular: 'mesothelioma'};
ok noun(q{zucca})->is_singular  => q{is_singular: 'zucca'};
ok noun(q{sephardi})->is_singular  => q{is_singular: 'sephardi'};
ok noun(q{surimono})->is_singular  => q{is_singular: 'surimono'};
ok noun(q{bon mot})->is_singular  => q{is_singular: 'bon mot'};
ok noun(q{mousetrap})->is_singular  => q{is_singular: 'mousetrap'};
ok noun(q{Londonese})->is_singular  => q{is_singular: 'Londonese'};
ok noun(q{gmina})->is_singular  => q{is_singular: 'gmina'};
ok noun(q{malleus})->is_singular  => q{is_singular: 'malleus'};
ok noun(q{cercus})->is_singular  => q{is_singular: 'cercus'};
ok noun(q{rhomboideus})->is_singular  => q{is_singular: 'rhomboideus'};
ok noun(q{sachverhalt})->is_singular  => q{is_singular: 'sachverhalt'};
ok noun(q{sheep})->is_singular  => q{is_singular: 'sheep'};
ok noun(q{mono})->is_singular  => q{is_singular: 'mono'};
ok noun(q{microbion})->is_singular  => q{is_singular: 'microbion'};
ok noun(q{ragazzo})->is_singular  => q{is_singular: 'ragazzo'};
ok noun(q{vorspiel})->is_singular  => q{is_singular: 'vorspiel'};
ok noun(q{concerto grosso})->is_singular  => q{is_singular: 'concerto grosso'};
ok noun(q{sphagnum})->is_singular  => q{is_singular: 'sphagnum'};
ok noun(q{ottoman})->is_singular  => q{is_singular: 'ottoman'};
ok noun(q{magma})->is_singular  => q{is_singular: 'magma'};
ok noun(q{coco})->is_singular  => q{is_singular: 'coco'};
ok noun(q{gyro})->is_singular  => q{is_singular: 'gyro'};
ok noun(q{nympheum})->is_singular  => q{is_singular: 'nympheum'};
ok noun(q{ri})->is_singular  => q{is_singular: 'ri'};
ok noun(q{toxius})->is_singular  => q{is_singular: 'toxius'};
ok noun(q{hormogonium})->is_singular  => q{is_singular: 'hormogonium'};
ok noun(q{hetaera})->is_singular  => q{is_singular: 'hetaera'};
ok noun(q{scapula})->is_singular  => q{is_singular: 'scapula'};
ok noun(q{rhizoma})->is_singular  => q{is_singular: 'rhizoma'};
ok noun(q{rete})->is_singular  => q{is_singular: 'rete'};
ok noun(q{vibraculum})->is_singular  => q{is_singular: 'vibraculum'};
ok noun(q{propodium})->is_singular  => q{is_singular: 'propodium'};
ok noun(q{maquereau})->is_singular  => q{is_singular: 'maquereau'};
ok noun(q{embryo})->is_singular  => q{is_singular: 'embryo'};
ok noun(q{mycorhiza})->is_singular  => q{is_singular: 'mycorhiza'};
ok noun(q{bacterium})->is_singular  => q{is_singular: 'bacterium'};
ok noun(q{Macassarese})->is_singular  => q{is_singular: 'Macassarese'};
ok noun(q{Ceylonese})->is_singular  => q{is_singular: 'Ceylonese'};
ok noun(q{juelet})->is_singular  => q{is_singular: 'juelet'};
ok noun(q{anta})->is_singular  => q{is_singular: 'anta'};
ok noun(q{mithraeum})->is_singular  => q{is_singular: 'mithraeum'};
ok noun(q{haustellum})->is_singular  => q{is_singular: 'haustellum'};
ok noun(q{pyrophorus})->is_singular  => q{is_singular: 'pyrophorus'};
ok noun(q{two star general})->is_singular  => q{is_singular: 'two star general'};
ok noun(q{chassis})->is_singular  => q{is_singular: 'chassis'};
ok noun(q{non-ens})->is_singular  => q{is_singular: 'non-ens'};
ok noun(q{devoto})->is_singular  => q{is_singular: 'devoto'};
ok noun(q{sensedatum})->is_singular  => q{is_singular: 'sensedatum'};
ok noun(q{lentiscus})->is_singular  => q{is_singular: 'lentiscus'};
ok noun(q{floccus})->is_singular  => q{is_singular: 'floccus'};
ok noun(q{ophiophagus})->is_singular  => q{is_singular: 'ophiophagus'};
ok noun(q{sirocco})->is_singular  => q{is_singular: 'sirocco'};
ok noun(q{pants})->is_singular  => q{is_singular: 'pants'};
ok noun(q{striola})->is_singular  => q{is_singular: 'striola'};
ok noun(q{odeum})->is_singular  => q{is_singular: 'odeum'};
ok noun(q{melisma})->is_singular  => q{is_singular: 'melisma'};
ok noun(q{saddo})->is_singular  => q{is_singular: 'saddo'};
ok noun(q{mantelletta})->is_singular  => q{is_singular: 'mantelletta'};
ok noun(q{blouse})->is_singular  => q{is_singular: 'blouse'};
ok noun(q{individuum})->is_singular  => q{is_singular: 'individuum'};
ok noun(q{Montenegro})->is_singular  => q{is_singular: 'Montenegro'};
ok noun(q{granula})->is_singular  => q{is_singular: 'granula'};
ok noun(q{thyrsus})->is_singular  => q{is_singular: 'thyrsus'};
ok noun(q{meniscus})->is_singular  => q{is_singular: 'meniscus'};
ok noun(q{faecula})->is_singular  => q{is_singular: 'faecula'};
ok noun(q{Orinoco})->is_singular  => q{is_singular: 'Orinoco'};
ok noun(q{argumentum})->is_singular  => q{is_singular: 'argumentum'};
ok noun(q{man milliner})->is_singular  => q{is_singular: 'man milliner'};
ok noun(q{intermaxilla})->is_singular  => q{is_singular: 'intermaxilla'};
ok noun(q{Tacoman})->is_singular  => q{is_singular: 'Tacoman'};
ok noun(q{washer up})->is_singular  => q{is_singular: 'washer up'};
ok noun(q{subsidium})->is_singular  => q{is_singular: 'subsidium'};
ok noun(q{syndendrium})->is_singular  => q{is_singular: 'syndendrium'};
ok noun(q{rom})->is_singular  => q{is_singular: 'rom'};
ok noun(q{epidermis})->is_singular  => q{is_singular: 'epidermis'};
ok noun(q{cul-de-sac})->is_singular  => q{is_singular: 'cul-de-sac'};
ok noun(q{Muranese})->is_singular  => q{is_singular: 'Muranese'};
ok noun(q{Kongoese})->is_singular  => q{is_singular: 'Kongoese'};
ok noun(q{Gabunese})->is_singular  => q{is_singular: 'Gabunese'};
ok noun(q{fibrilla})->is_singular  => q{is_singular: 'fibrilla'};
ok noun(q{Faro})->is_singular  => q{is_singular: 'Faro'};
ok noun(q{ephemera})->is_singular  => q{is_singular: 'ephemera'};
ok noun(q{knopper})->is_singular  => q{is_singular: 'knopper'};
ok noun(q{brother})->is_singular  => q{is_singular: 'brother'};
ok noun(q{milieu interieur})->is_singular  => q{is_singular: 'milieu interieur'};
ok noun(q{monsignore})->is_singular  => q{is_singular: 'monsignore'};
ok noun(q{kimono})->is_singular  => q{is_singular: 'kimono'};
ok noun(q{afrit})->is_singular  => q{is_singular: 'afrit'};
ok noun(q{peronium})->is_singular  => q{is_singular: 'peronium'};
ok noun(q{thyridium})->is_singular  => q{is_singular: 'thyridium'};
ok noun(q{mew})->is_singular  => q{is_singular: 'mew'};
ok noun(q{them})->is_singular  => q{is_singular: 'them'};
ok noun(q{ricercar})->is_singular  => q{is_singular: 'ricercar'};
ok noun(q{mongoose})->is_singular  => q{is_singular: 'mongoose'};
ok noun(q{Tirolese})->is_singular  => q{is_singular: 'Tirolese'};
ok noun(q{porron})->is_singular  => q{is_singular: 'porron'};
ok noun(q{rhinophyma})->is_singular  => q{is_singular: 'rhinophyma'};
ok noun(q{angioma})->is_singular  => q{is_singular: 'angioma'};
ok noun(q{gringo})->is_singular  => q{is_singular: 'gringo'};
ok noun(q{viaticum})->is_singular  => q{is_singular: 'viaticum'};
ok noun(q{famulus})->is_singular  => q{is_singular: 'famulus'};
ok noun(q{malagma})->is_singular  => q{is_singular: 'malagma'};
ok noun(q{velarium})->is_singular  => q{is_singular: 'velarium'};
ok noun(q{ovolo})->is_singular  => q{is_singular: 'ovolo'};
ok noun(q{Maputo})->is_singular  => q{is_singular: 'Maputo'};
ok noun(q{Boto})->is_singular  => q{is_singular: 'Boto'};
ok noun(q{condottiere})->is_singular  => q{is_singular: 'condottiere'};
ok noun(q{nouveau pauvre})->is_singular  => q{is_singular: 'nouveau pauvre'};
ok noun(q{scutellum})->is_singular  => q{is_singular: 'scutellum'};
ok noun(q{albino})->is_singular  => q{is_singular: 'albino'};
ok noun(q{basilica})->is_singular  => q{is_singular: 'basilica'};
ok noun(q{mimosa})->is_singular  => q{is_singular: 'mimosa'};
ok noun(q{Romagnese})->is_singular  => q{is_singular: 'Romagnese'};
ok noun(q{compendium})->is_singular  => q{is_singular: 'compendium'};
ok noun(q{politico})->is_singular  => q{is_singular: 'politico'};
ok noun(q{barrico})->is_singular  => q{is_singular: 'barrico'};
ok noun(q{soshi})->is_singular  => q{is_singular: 'soshi'};
ok noun(q{sensillum})->is_singular  => q{is_singular: 'sensillum'};
ok noun(q{sbirro})->is_singular  => q{is_singular: 'sbirro'};
ok noun(q{pathos})->is_singular  => q{is_singular: 'pathos'};
ok noun(q{telamon})->is_singular  => q{is_singular: 'telamon'};
ok noun(q{cilantro})->is_singular  => q{is_singular: 'cilantro'};
ok noun(q{cantharus})->is_singular  => q{is_singular: 'cantharus'};
ok noun(q{Hiroshiman})->is_singular  => q{is_singular: 'Hiroshiman'};
ok noun(q{nucleolonema})->is_singular  => q{is_singular: 'nucleolonema'};
ok noun(q{matin})->is_singular  => q{is_singular: 'matin'};
ok noun(q{crus})->is_singular  => q{is_singular: 'crus'};
ok noun(q{portiforium})->is_singular  => q{is_singular: 'portiforium'};
ok noun(q{monas})->is_singular  => q{is_singular: 'monas'};
ok noun(q{Hoosierese})->is_singular  => q{is_singular: 'Hoosierese'};
ok noun(q{vermicello})->is_singular  => q{is_singular: 'vermicello'};
ok noun(q{momentum})->is_singular  => q{is_singular: 'momentum'};
ok noun(q{leproma})->is_singular  => q{is_singular: 'leproma'};
ok noun(q{pinax})->is_singular  => q{is_singular: 'pinax'};
ok noun(q{plateau})->is_singular  => q{is_singular: 'plateau'};
ok noun(q{stasimon})->is_singular  => q{is_singular: 'stasimon'};
ok noun(q{precis})->is_singular  => q{is_singular: 'precis'};
ok noun(q{fossa})->is_singular  => q{is_singular: 'fossa'};
ok noun(q{nse})->is_singular  => q{is_singular: 'nse'};
ok noun(q{hamulus})->is_singular  => q{is_singular: 'hamulus'};
ok noun(q{tobacco})->is_singular  => q{is_singular: 'tobacco'};
ok noun(q{wreath})->is_singular  => q{is_singular: 'wreath'};
ok noun(q{collegium})->is_singular  => q{is_singular: 'collegium'};
ok noun(q{libretto})->is_singular  => q{is_singular: 'libretto'};
ok noun(q{platypus})->is_singular  => q{is_singular: 'platypus'};
ok noun(q{formula})->is_singular  => q{is_singular: 'formula'};
ok noun(q{apex})->is_singular  => q{is_singular: 'apex'};
ok noun(q{corpusculum})->is_singular  => q{is_singular: 'corpusculum'};
ok noun(q{politbureau})->is_singular  => q{is_singular: 'politbureau'};
ok noun(q{oxymoron})->is_singular  => q{is_singular: 'oxymoron'};
ok noun(q{imbrex})->is_singular  => q{is_singular: 'imbrex'};
ok noun(q{synedrium})->is_singular  => q{is_singular: 'synedrium'};
ok noun(q{bongo})->is_singular  => q{is_singular: 'bongo'};
ok noun(q{pharmakos})->is_singular  => q{is_singular: 'pharmakos'};
ok noun(q{pollinarium})->is_singular  => q{is_singular: 'pollinarium'};
ok noun(q{embryoma})->is_singular  => q{is_singular: 'embryoma'};
ok noun(q{tolkach})->is_singular  => q{is_singular: 'tolkach'};
ok noun(q{corps})->is_singular  => q{is_singular: 'corps'};
ok noun(q{motto})->is_singular  => q{is_singular: 'motto'};
ok noun(q{major general})->is_singular  => q{is_singular: 'major general'};
ok noun(q{bias})->is_singular  => q{is_singular: 'bias'};
ok noun(q{squadra})->is_singular  => q{is_singular: 'squadra'};
ok noun(q{chaeta})->is_singular  => q{is_singular: 'chaeta'};
ok noun(q{hers})->is_singular  => q{is_singular: 'hers'};
ok noun(q{whoever})->is_singular  => q{is_singular: 'whoever'};
ok noun(q{Kokako})->is_singular  => q{is_singular: 'Kokako'};
ok noun(q{syllabarium})->is_singular  => q{is_singular: 'syllabarium'};
ok noun(q{fro})->is_singular  => q{is_singular: 'fro'};
ok noun(q{striatum})->is_singular  => q{is_singular: 'striatum'};
ok noun(q{succus})->is_singular  => q{is_singular: 'succus'};
ok noun(q{tenia})->is_singular  => q{is_singular: 'tenia'};
ok noun(q{silo})->is_singular  => q{is_singular: 'silo'};
ok noun(q{yo-yo})->is_singular  => q{is_singular: 'yo-yo'};
ok noun(q{basis})->is_singular  => q{is_singular: 'basis'};
ok noun(q{quinquennium})->is_singular  => q{is_singular: 'quinquennium'};
ok noun(q{snipe})->is_singular  => q{is_singular: 'snipe'};
ok noun(q{mondo})->is_singular  => q{is_singular: 'mondo'};
ok noun(q{gonimium})->is_singular  => q{is_singular: 'gonimium'};
ok noun(q{info})->is_singular  => q{is_singular: 'info'};
ok noun(q{coney})->is_singular  => q{is_singular: 'coney'};
ok noun(q{latex})->is_singular  => q{is_singular: 'latex'};
ok noun(q{propleuron})->is_singular  => q{is_singular: 'propleuron'};
ok noun(q{vestigium})->is_singular  => q{is_singular: 'vestigium'};
ok noun(q{abstractum})->is_singular  => q{is_singular: 'abstractum'};
ok noun(q{bersagliere})->is_singular  => q{is_singular: 'bersagliere'};
ok noun(q{nubecula})->is_singular  => q{is_singular: 'nubecula'};
ok noun(q{psycho})->is_singular  => q{is_singular: 'psycho'};
ok noun(q{syncytium})->is_singular  => q{is_singular: 'syncytium'};
ok noun(q{tragus})->is_singular  => q{is_singular: 'tragus'};
ok noun(q{species})->is_singular  => q{is_singular: 'species'};
ok noun(q{hyperbaton})->is_singular  => q{is_singular: 'hyperbaton'};
ok noun(q{coagulum})->is_singular  => q{is_singular: 'coagulum'};
ok noun(q{thorax})->is_singular  => q{is_singular: 'thorax'};
ok noun(q{forum})->is_singular  => q{is_singular: 'forum'};
ok noun(q{ganglion})->is_singular  => q{is_singular: 'ganglion'};
ok noun(q{alan})->is_singular  => q{is_singular: 'alan'};
ok noun(q{kouros})->is_singular  => q{is_singular: 'kouros'};
ok noun(q{shochet})->is_singular  => q{is_singular: 'shochet'};
ok noun(q{dentalium})->is_singular  => q{is_singular: 'dentalium'};
ok noun(q{gametangium})->is_singular  => q{is_singular: 'gametangium'};
ok noun(q{suffrutex})->is_singular  => q{is_singular: 'suffrutex'};
ok noun(q{castrum})->is_singular  => q{is_singular: 'castrum'};
ok noun(q{leman})->is_singular  => q{is_singular: 'leman'};
ok noun(q{soredium})->is_singular  => q{is_singular: 'soredium'};
ok noun(q{ox})->is_singular  => q{is_singular: 'ox'};
ok noun(q{charisma})->is_singular  => q{is_singular: 'charisma'};
ok noun(q{pulsellum})->is_singular  => q{is_singular: 'pulsellum'};
ok noun(q{synedrion})->is_singular  => q{is_singular: 'synedrion'};
ok noun(q{nexus})->is_singular  => q{is_singular: 'nexus'};
ok noun(q{lar})->is_singular  => q{is_singular: 'lar'};
ok noun(q{Viennese})->is_singular  => q{is_singular: 'Viennese'};
ok noun(q{vasculum})->is_singular  => q{is_singular: 'vasculum'};
ok noun(q{lacunar})->is_singular  => q{is_singular: 'lacunar'};
ok noun(q{larnax})->is_singular  => q{is_singular: 'larnax'};
ok noun(q{lymphoma})->is_singular  => q{is_singular: 'lymphoma'};
ok noun(q{ovarium})->is_singular  => q{is_singular: 'ovarium'};
ok noun(q{headquarters})->is_singular  => q{is_singular: 'headquarters'};
ok noun(q{vibrato})->is_singular  => q{is_singular: 'vibrato'};
ok noun(q{Sikkimese})->is_singular  => q{is_singular: 'Sikkimese'};
ok noun(q{synechia})->is_singular  => q{is_singular: 'synechia'};
ok noun(q{soma})->is_singular  => q{is_singular: 'soma'};
ok noun(q{rococo})->is_singular  => q{is_singular: 'rococo'};
ok noun(q{froe})->is_singular  => q{is_singular: 'froe'};
ok noun(q{statera})->is_singular  => q{is_singular: 'statera'};
ok noun(q{sequela})->is_singular  => q{is_singular: 'sequela'};
ok noun(q{arcanum})->is_singular  => q{is_singular: 'arcanum'};
ok noun(q{corona})->is_singular  => q{is_singular: 'corona'};
ok noun(q{breakaway})->is_singular  => q{is_singular: 'breakaway'};
ok noun(q{hetman})->is_singular  => q{is_singular: 'hetman'};
ok noun(q{parhelion})->is_singular  => q{is_singular: 'parhelion'};
ok noun(q{refugium})->is_singular  => q{is_singular: 'refugium'};
ok noun(q{corno})->is_singular  => q{is_singular: 'corno'};
ok noun(q{Kakapo})->is_singular  => q{is_singular: 'Kakapo'};
ok noun(q{altorelievo})->is_singular  => q{is_singular: 'altorelievo'};
ok noun(q{extispex})->is_singular  => q{is_singular: 'extispex'};
ok noun(q{wadi})->is_singular  => q{is_singular: 'wadi'};
ok noun(q{harman})->is_singular  => q{is_singular: 'harman'};
ok noun(q{Sacramento})->is_singular  => q{is_singular: 'Sacramento'};
ok noun(q{neutrino})->is_singular  => q{is_singular: 'neutrino'};
ok noun(q{glioma})->is_singular  => q{is_singular: 'glioma'};
ok noun(q{dais})->is_singular  => q{is_singular: 'dais'};
ok noun(q{octavo})->is_singular  => q{is_singular: 'octavo'};
ok noun(q{Havanese})->is_singular  => q{is_singular: 'Havanese'};
ok noun(q{cystoma})->is_singular  => q{is_singular: 'cystoma'};
ok noun(q{ethos})->is_singular  => q{is_singular: 'ethos'};
ok noun(q{erf})->is_singular  => q{is_singular: 'erf'};
ok noun(q{rhynchodaeum})->is_singular  => q{is_singular: 'rhynchodaeum'};
ok noun(q{manteau})->is_singular  => q{is_singular: 'manteau'};
ok noun(q{amorino})->is_singular  => q{is_singular: 'amorino'};
ok noun(q{Nicobarese})->is_singular  => q{is_singular: 'Nicobarese'};
ok noun(q{bruschetta})->is_singular  => q{is_singular: 'bruschetta'};
ok noun(q{tarantata})->is_singular  => q{is_singular: 'tarantata'};
ok noun(q{thelycum})->is_singular  => q{is_singular: 'thelycum'};
ok noun(q{avicularium})->is_singular  => q{is_singular: 'avicularium'};
ok noun(q{podere})->is_singular  => q{is_singular: 'podere'};
ok noun(q{bath})->is_singular  => q{is_singular: 'bath'};
ok noun(q{prima ballerina})->is_singular  => q{is_singular: 'prima ballerina'};
ok noun(q{libido})->is_singular  => q{is_singular: 'libido'};
ok noun(q{2 star general})->is_singular  => q{is_singular: '2 star general'};
ok noun(q{triclinium})->is_singular  => q{is_singular: 'triclinium'};
ok noun(q{hapteron})->is_singular  => q{is_singular: 'hapteron'};
ok noun(q{triens})->is_singular  => q{is_singular: 'triens'};
ok noun(q{loco})->is_singular  => q{is_singular: 'loco'};
ok noun(q{ilium})->is_singular  => q{is_singular: 'ilium'};
ok noun(q{megatherium})->is_singular  => q{is_singular: 'megatherium'};
ok noun(q{set off})->is_singular  => q{is_singular: 'set off'};
ok noun(q{plesiosaurus})->is_singular  => q{is_singular: 'plesiosaurus'};
ok noun(q{jackanapes})->is_singular  => q{is_singular: 'jackanapes'};
ok noun(q{break-away})->is_singular  => q{is_singular: 'break-away'};
ok noun(q{phalangium})->is_singular  => q{is_singular: 'phalangium'};
ok noun(q{signum})->is_singular  => q{is_singular: 'signum'};
ok noun(q{nockerl})->is_singular  => q{is_singular: 'nockerl'};
ok noun(q{stomodaeum})->is_singular  => q{is_singular: 'stomodaeum'};
ok noun(q{editio princeps})->is_singular  => q{is_singular: 'editio princeps'};
ok noun(q{adieu})->is_singular  => q{is_singular: 'adieu'};
ok noun(q{auslese})->is_singular  => q{is_singular: 'auslese'};
ok noun(q{urodaeum})->is_singular  => q{is_singular: 'urodaeum'};
ok noun(q{solidus})->is_singular  => q{is_singular: 'solidus'};
ok noun(q{meliceris})->is_singular  => q{is_singular: 'meliceris'};
ok noun(q{parabola})->is_singular  => q{is_singular: 'parabola'};
ok noun(q{hymenium})->is_singular  => q{is_singular: 'hymenium'};
ok noun(q{protococcus})->is_singular  => q{is_singular: 'protococcus'};
ok noun(q{Gilbertese})->is_singular  => q{is_singular: 'Gilbertese'};
ok noun(q{Calabrese})->is_singular  => q{is_singular: 'Calabrese'};
ok noun(q{areola})->is_singular  => q{is_singular: 'areola'};
ok noun(q{myo})->is_singular  => q{is_singular: 'myo'};
ok noun(q{haruspex})->is_singular  => q{is_singular: 'haruspex'};
ok noun(q{potestas})->is_singular  => q{is_singular: 'potestas'};
ok noun(q{carex})->is_singular  => q{is_singular: 'carex'};
ok noun(q{toxoplasma})->is_singular  => q{is_singular: 'toxoplasma'};
ok noun(q{ens rationis})->is_singular  => q{is_singular: 'ens rationis'};
ok noun(q{Amboinese})->is_singular  => q{is_singular: 'Amboinese'};
ok noun(q{trichina})->is_singular  => q{is_singular: 'trichina'};
ok noun(q{auto de fe})->is_singular  => q{is_singular: 'auto de fe'};
ok noun(q{centumvir})->is_singular  => q{is_singular: 'centumvir'};
ok noun(q{news})->is_singular  => q{is_singular: 'news'};
ok noun(q{operculum})->is_singular  => q{is_singular: 'operculum'};
ok noun(q{ritardando})->is_singular  => q{is_singular: 'ritardando'};
ok noun(q{Nenets})->is_singular  => q{is_singular: 'Nenets'};
ok noun(q{magus})->is_singular  => q{is_singular: 'magus'};
ok noun(q{appendix})->is_singular  => q{is_singular: 'appendix'};
ok noun(q{pyralis})->is_singular  => q{is_singular: 'pyralis'};
ok noun(q{fraenum})->is_singular  => q{is_singular: 'fraenum'};
ok noun(q{celia})->is_singular  => q{is_singular: 'celia'};
ok noun(q{bacillus})->is_singular  => q{is_singular: 'bacillus'};
ok noun(q{sumo})->is_singular  => q{is_singular: 'sumo'};
ok noun(q{versiculus})->is_singular  => q{is_singular: 'versiculus'};
ok noun(q{lord lieutenant})->is_singular  => q{is_singular: 'lord lieutenant'};
ok noun(q{Filipino})->is_singular  => q{is_singular: 'Filipino'};
ok noun(q{monochasium})->is_singular  => q{is_singular: 'monochasium'};
ok noun(q{parvenu})->is_singular  => q{is_singular: 'parvenu'};
ok noun(q{Congoese})->is_singular  => q{is_singular: 'Congoese'};
ok noun(q{panino})->is_singular  => q{is_singular: 'panino'};
ok noun(q{iris})->is_singular  => q{is_singular: 'iris'};
ok noun(q{secundagravida})->is_singular  => q{is_singular: 'secundagravida'};
ok noun(q{fricandeau})->is_singular  => q{is_singular: 'fricandeau'};
ok noun(q{farman})->is_singular  => q{is_singular: 'farman'};
ok noun(q{ens reale})->is_singular  => q{is_singular: 'ens reale'};
ok noun(q{plankter})->is_singular  => q{is_singular: 'plankter'};
ok noun(q{peridium})->is_singular  => q{is_singular: 'peridium'};
ok noun(q{neurinoma})->is_singular  => q{is_singular: 'neurinoma'};
ok noun(q{leaf})->is_singular  => q{is_singular: 'leaf'};
ok noun(q{busto})->is_singular  => q{is_singular: 'busto'};
ok noun(q{beerenauslese})->is_singular  => q{is_singular: 'beerenauslese'};
ok noun(q{status})->is_singular  => q{is_singular: 'status'};
ok noun(q{phylum})->is_singular  => q{is_singular: 'phylum'};
ok noun(q{parergon})->is_singular  => q{is_singular: 'parergon'};
ok noun(q{auspex})->is_singular  => q{is_singular: 'auspex'};
ok noun(q{musique concrete})->is_singular  => q{is_singular: 'musique concrete'};
ok noun(q{vibex})->is_singular  => q{is_singular: 'vibex'};
ok noun(q{tortrix})->is_singular  => q{is_singular: 'tortrix'};
ok noun(q{pyxidium})->is_singular  => q{is_singular: 'pyxidium'};
ok noun(q{kernos})->is_singular  => q{is_singular: 'kernos'};
ok noun(q{placitum})->is_singular  => q{is_singular: 'placitum'};
ok noun(q{goose})->is_singular  => q{is_singular: 'goose'};
ok noun(q{galla})->is_singular  => q{is_singular: 'galla'};
ok noun(q{trilby})->is_singular  => q{is_singular: 'trilby'};
ok noun(q{ambulacrum})->is_singular  => q{is_singular: 'ambulacrum'};
ok noun(q{Hainanese})->is_singular  => q{is_singular: 'Hainanese'};
ok noun(q{triradius})->is_singular  => q{is_singular: 'triradius'};
ok noun(q{hypolimnion})->is_singular  => q{is_singular: 'hypolimnion'};
ok noun(q{polythecium})->is_singular  => q{is_singular: 'polythecium'};
ok noun(q{gousblom})->is_singular  => q{is_singular: 'gousblom'};
ok noun(q{podion})->is_singular  => q{is_singular: 'podion'};
ok noun(q{xiphiplastron})->is_singular  => q{is_singular: 'xiphiplastron'};
ok noun(q{patagium})->is_singular  => q{is_singular: 'patagium'};
ok noun(q{sacrum})->is_singular  => q{is_singular: 'sacrum'};
ok noun(q{arf})->is_singular  => q{is_singular: 'arf'};
ok noun(q{carcinoma})->is_singular  => q{is_singular: 'carcinoma'};
ok noun(q{paraselene})->is_singular  => q{is_singular: 'paraselene'};
ok noun(q{finger end})->is_singular  => q{is_singular: 'finger end'};
ok noun(q{6 star general})->is_singular  => q{is_singular: '6 star general'};
ok noun(q{Vermontese})->is_singular  => q{is_singular: 'Vermontese'};
ok noun(q{chitarrone})->is_singular  => q{is_singular: 'chitarrone'};
ok noun(q{toe})->is_singular  => q{is_singular: 'toe'};
ok noun(q{doe})->is_singular  => q{is_singular: 'doe'};
ok noun(q{competent})->is_singular  => q{is_singular: 'competent'};
ok noun(q{ale-wife})->is_singular  => q{is_singular: 'ale-wife'};
ok noun(q{ovulum})->is_singular  => q{is_singular: 'ovulum'};
ok noun(q{mouth})->is_singular  => q{is_singular: 'mouth'};
ok noun(q{meta})->is_singular  => q{is_singular: 'meta'};
ok noun(q{bulla})->is_singular  => q{is_singular: 'bulla'};
ok noun(q{felsenmeer})->is_singular  => q{is_singular: 'felsenmeer'};
ok noun(q{somaten})->is_singular  => q{is_singular: 'somaten'};
ok noun(q{gonangium})->is_singular  => q{is_singular: 'gonangium'};
ok noun(q{caffe macchiato})->is_singular  => q{is_singular: 'caffe macchiato'};
ok noun(q{Amoyese})->is_singular  => q{is_singular: 'Amoyese'};
ok noun(q{involucrum})->is_singular  => q{is_singular: 'involucrum'};
ok noun(q{incubus})->is_singular  => q{is_singular: 'incubus'};
ok noun(q{penni})->is_singular  => q{is_singular: 'penni'};
ok noun(q{intertrigo})->is_singular  => q{is_singular: 'intertrigo'};
ok noun(q{gizmo})->is_singular  => q{is_singular: 'gizmo'};
ok noun(q{wife})->is_singular  => q{is_singular: 'wife'};
ok noun(q{sanatorium})->is_singular  => q{is_singular: 'sanatorium'};
ok noun(q{elk})->is_singular  => q{is_singular: 'elk'};
ok noun(q{canzonetta})->is_singular  => q{is_singular: 'canzonetta'};
ok noun(q{stomach})->is_singular  => q{is_singular: 'stomach'};
ok noun(q{plexus})->is_singular  => q{is_singular: 'plexus'};
ok noun(q{pinna})->is_singular  => q{is_singular: 'pinna'};
ok noun(q{sporodochium})->is_singular  => q{is_singular: 'sporodochium'};
ok noun(q{pelta})->is_singular  => q{is_singular: 'pelta'};
ok noun(q{shorts})->is_singular  => q{is_singular: 'shorts'};
ok noun(q{sanctum sanctorum})->is_singular  => q{is_singular: 'sanctum sanctorum'};
ok noun(q{whose})->is_singular  => q{is_singular: 'whose'};
ok noun(q{poise})->is_singular  => q{is_singular: 'poise'};
ok noun(q{globigerina})->is_singular  => q{is_singular: 'globigerina'};
ok noun(q{reich})->is_singular  => q{is_singular: 'reich'};
ok noun(q{vaalpens})->is_singular  => q{is_singular: 'vaalpens'};
ok noun(q{explicandum})->is_singular  => q{is_singular: 'explicandum'};
ok noun(q{zoaea})->is_singular  => q{is_singular: 'zoaea'};
ok noun(q{bursitis})->is_singular  => q{is_singular: 'bursitis'};
ok noun(q{guy})->is_singular  => q{is_singular: 'guy'};
ok noun(q{manifesto})->is_singular  => q{is_singular: 'manifesto'};
ok noun(q{enema})->is_singular  => q{is_singular: 'enema'};
ok noun(q{uterus})->is_singular  => q{is_singular: 'uterus'};
ok noun(q{parison})->is_singular  => q{is_singular: 'parison'};
ok noun(q{5 star general})->is_singular  => q{is_singular: '5 star general'};
ok noun(q{planctus})->is_singular  => q{is_singular: 'planctus'};
ok noun(q{prolegomenon})->is_singular  => q{is_singular: 'prolegomenon'};
ok noun(q{mackerel})->is_singular  => q{is_singular: 'mackerel'};
ok noun(q{vesicula})->is_singular  => q{is_singular: 'vesicula'};
ok noun(q{sezession})->is_singular  => q{is_singular: 'sezession'};
ok noun(q{lingo})->is_singular  => q{is_singular: 'lingo'};
ok noun(q{pendulum})->is_singular  => q{is_singular: 'pendulum'};
ok noun(q{Idaho})->is_singular  => q{is_singular: 'Idaho'};
ok noun(q{cubiculum})->is_singular  => q{is_singular: 'cubiculum'};
ok noun(q{contagium})->is_singular  => q{is_singular: 'contagium'};
ok noun(q{replum})->is_singular  => q{is_singular: 'replum'};
ok noun(q{cynocephalus})->is_singular  => q{is_singular: 'cynocephalus'};
ok noun(q{bursa})->is_singular  => q{is_singular: 'bursa'};
ok noun(q{anthodium})->is_singular  => q{is_singular: 'anthodium'};
ok noun(q{sipunculus})->is_singular  => q{is_singular: 'sipunculus'};
ok noun(q{vagina})->is_singular  => q{is_singular: 'vagina'};
ok noun(q{scoria})->is_singular  => q{is_singular: 'scoria'};
ok noun(q{jugum})->is_singular  => q{is_singular: 'jugum'};
ok noun(q{spermatium})->is_singular  => q{is_singular: 'spermatium'};
ok noun(q{legomenon})->is_singular  => q{is_singular: 'legomenon'};
ok noun(q{ommatidium})->is_singular  => q{is_singular: 'ommatidium'};
ok noun(q{pogo})->is_singular  => q{is_singular: 'pogo'};
ok noun(q{cul de four})->is_singular  => q{is_singular: 'cul de four'};
ok noun(q{noumenon})->is_singular  => q{is_singular: 'noumenon'};
ok noun(q{Faroese})->is_singular  => q{is_singular: 'Faroese'};
ok noun(q{spadix})->is_singular  => q{is_singular: 'spadix'};
ok noun(q{stomion})->is_singular  => q{is_singular: 'stomion'};
ok noun(q{linea})->is_singular  => q{is_singular: 'linea'};
ok noun(q{flagellum})->is_singular  => q{is_singular: 'flagellum'};
ok noun(q{stiletto})->is_singular  => q{is_singular: 'stiletto'};
ok noun(q{studium generale})->is_singular  => q{is_singular: 'studium generale'};
ok noun(q{tombarolo})->is_singular  => q{is_singular: 'tombarolo'};
ok noun(q{myxoma})->is_singular  => q{is_singular: 'myxoma'};
ok noun(q{palea})->is_singular  => q{is_singular: 'palea'};
ok noun(q{demo})->is_singular  => q{is_singular: 'demo'};
ok noun(q{macaroni})->is_singular  => q{is_singular: 'macaroni'};
ok noun(q{afreet})->is_singular  => q{is_singular: 'afreet'};
ok noun(q{ngwee})->is_singular  => q{is_singular: 'ngwee'};
ok noun(q{pallium})->is_singular  => q{is_singular: 'pallium'};
ok noun(q{synapticula})->is_singular  => q{is_singular: 'synapticula'};
ok noun(q{focus})->is_singular  => q{is_singular: 'focus'};
ok noun(q{bierstube})->is_singular  => q{is_singular: 'bierstube'};
ok noun(q{enigma})->is_singular  => q{is_singular: 'enigma'};
ok noun(q{contadina})->is_singular  => q{is_singular: 'contadina'};
ok noun(q{Yamoussoukro})->is_singular  => q{is_singular: 'Yamoussoukro'};
ok noun(q{conoscente})->is_singular  => q{is_singular: 'conoscente'};
ok noun(q{efreet})->is_singular  => q{is_singular: 'efreet'};
ok noun(q{raggare})->is_singular  => q{is_singular: 'raggare'};
ok noun(q{blemya})->is_singular  => q{is_singular: 'blemya'};
ok noun(q{Porto Novo})->is_singular  => q{is_singular: 'Porto Novo'};
ok noun(q{seta})->is_singular  => q{is_singular: 'seta'};
ok noun(q{genus})->is_singular  => q{is_singular: 'genus'};
ok noun(q{what})->is_singular  => q{is_singular: 'what'};
ok noun(q{thymiaterion})->is_singular  => q{is_singular: 'thymiaterion'};
ok noun(q{pincers})->is_singular  => q{is_singular: 'pincers'};
ok noun(q{spatha})->is_singular  => q{is_singular: 'spatha'};
ok noun(q{parabolanus})->is_singular  => q{is_singular: 'parabolanus'};
ok noun(q{pteropus})->is_singular  => q{is_singular: 'pteropus'};
ok noun(q{pied noir})->is_singular  => q{is_singular: 'pied noir'};
ok noun(q{territorium})->is_singular  => q{is_singular: 'territorium'};
ok noun(q{noema})->is_singular  => q{is_singular: 'noema'};
ok noun(q{serpula})->is_singular  => q{is_singular: 'serpula'};
ok noun(q{jacobus})->is_singular  => q{is_singular: 'jacobus'};
ok noun(q{prodromus})->is_singular  => q{is_singular: 'prodromus'};
ok noun(q{sedile})->is_singular  => q{is_singular: 'sedile'};
ok noun(q{army corps general})->is_singular  => q{is_singular: 'army corps general'};
ok noun(q{memorandum})->is_singular  => q{is_singular: 'memorandum'};
ok noun(q{trapezohedron})->is_singular  => q{is_singular: 'trapezohedron'};
ok noun(q{laika})->is_singular  => q{is_singular: 'laika'};
ok noun(q{prosencephalon})->is_singular  => q{is_singular: 'prosencephalon'};
ok noun(q{umbilicus})->is_singular  => q{is_singular: 'umbilicus'};
ok noun(q{limes})->is_singular  => q{is_singular: 'limes'};
ok noun(q{Burman})->is_singular  => q{is_singular: 'Burman'};
ok noun(q{haustorium})->is_singular  => q{is_singular: 'haustorium'};
ok noun(q{mouse})->is_singular  => q{is_singular: 'mouse'};
ok noun(q{arango})->is_singular  => q{is_singular: 'arango'};
ok noun(q{hemera})->is_singular  => q{is_singular: 'hemera'};
ok noun(q{modello})->is_singular  => q{is_singular: 'modello'};
ok noun(q{stornello})->is_singular  => q{is_singular: 'stornello'};
ok noun(q{lithodomus})->is_singular  => q{is_singular: 'lithodomus'};
ok noun(q{cow})->is_singular  => q{is_singular: 'cow'};
ok noun(q{contango})->is_singular  => q{is_singular: 'contango'};
ok noun(q{tropis})->is_singular  => q{is_singular: 'tropis'};
ok noun(q{gymnasium})->is_singular  => q{is_singular: 'gymnasium'};
ok noun(q{acinus})->is_singular  => q{is_singular: 'acinus'};
ok noun(q{plasmoma})->is_singular  => q{is_singular: 'plasmoma'};
ok noun(q{schistosomulum})->is_singular  => q{is_singular: 'schistosomulum'};
ok noun(q{apsis})->is_singular  => q{is_singular: 'apsis'};
ok noun(q{vomica})->is_singular  => q{is_singular: 'vomica'};
ok noun(q{pillie})->is_singular  => q{is_singular: 'pillie'};
ok noun(q{bolus})->is_singular  => q{is_singular: 'bolus'};
ok noun(q{magnum opus})->is_singular  => q{is_singular: 'magnum opus'};
ok noun(q{tuber})->is_singular  => q{is_singular: 'tuber'};
ok noun(q{Johnsonese})->is_singular  => q{is_singular: 'Johnsonese'};
ok noun(q{Tonkinese})->is_singular  => q{is_singular: 'Tonkinese'};
ok noun(q{Sarajevo})->is_singular  => q{is_singular: 'Sarajevo'};
ok noun(q{Hottentotese})->is_singular  => q{is_singular: 'Hottentotese'};
ok noun(q{thief})->is_singular  => q{is_singular: 'thief'};
ok noun(q{Navarrese})->is_singular  => q{is_singular: 'Navarrese'};
ok noun(q{prima donna})->is_singular  => q{is_singular: 'prima donna'};
ok noun(q{archegonium})->is_singular  => q{is_singular: 'archegonium'};
ok noun(q{Parmese})->is_singular  => q{is_singular: 'Parmese'};
ok noun(q{to})->is_singular  => q{is_singular: 'to'};
ok noun(q{do})->is_singular  => q{is_singular: 'do'};
ok noun(q{one-star general})->is_singular  => q{is_singular: 'one-star general'};
ok noun(q{astrocytoma})->is_singular  => q{is_singular: 'astrocytoma'};
ok noun(q{Yakiman})->is_singular  => q{is_singular: 'Yakiman'};
ok noun(q{labrum})->is_singular  => q{is_singular: 'labrum'};
ok noun(q{rilievo})->is_singular  => q{is_singular: 'rilievo'};
ok noun(q{denkmal})->is_singular  => q{is_singular: 'denkmal'};
ok noun(q{macro})->is_singular  => q{is_singular: 'macro'};
ok noun(q{gravamen})->is_singular  => q{is_singular: 'gravamen'};
ok noun(q{Americanese})->is_singular  => q{is_singular: 'Americanese'};
ok noun(q{spermatheca})->is_singular  => q{is_singular: 'spermatheca'};
ok noun(q{4-star general})->is_singular  => q{is_singular: '4-star general'};
ok noun(q{cul-de-lampe})->is_singular  => q{is_singular: 'cul-de-lampe'};
ok noun(q{Lebanese})->is_singular  => q{is_singular: 'Lebanese'};
ok noun(q{dictum})->is_singular  => q{is_singular: 'dictum'};
ok noun(q{manservant})->is_singular  => q{is_singular: 'manservant'};
ok noun(q{themself})->is_singular  => q{is_singular: 'themself'};
ok noun(q{trichidium})->is_singular  => q{is_singular: 'trichidium'};
ok noun(q{chorus})->is_singular  => q{is_singular: 'chorus'};
ok noun(q{meretrix})->is_singular  => q{is_singular: 'meretrix'};
ok noun(q{synangium})->is_singular  => q{is_singular: 'synangium'};
ok noun(q{bandit})->is_singular  => q{is_singular: 'bandit'};
ok noun(q{cabaletta})->is_singular  => q{is_singular: 'cabaletta'};
ok noun(q{espanol})->is_singular  => q{is_singular: 'espanol'};
ok noun(q{memo})->is_singular  => q{is_singular: 'memo'};
ok noun(q{micro})->is_singular  => q{is_singular: 'micro'};
ok noun(q{tonneau})->is_singular  => q{is_singular: 'tonneau'};
ok noun(q{septemvir})->is_singular  => q{is_singular: 'septemvir'};
ok noun(q{comatula})->is_singular  => q{is_singular: 'comatula'};
ok noun(q{stemma})->is_singular  => q{is_singular: 'stemma'};
ok noun(q{modius})->is_singular  => q{is_singular: 'modius'};
ok noun(q{figurante})->is_singular  => q{is_singular: 'figurante'};
ok noun(q{cremaster})->is_singular  => q{is_singular: 'cremaster'};
ok noun(q{lemniscus})->is_singular  => q{is_singular: 'lemniscus'};
ok noun(q{pullus})->is_singular  => q{is_singular: 'pullus'};
ok noun(q{limbo})->is_singular  => q{is_singular: 'limbo'};
ok noun(q{mafiosa})->is_singular  => q{is_singular: 'mafiosa'};
ok noun(q{caduceus})->is_singular  => q{is_singular: 'caduceus'};
ok noun(q{synesthesia})->is_singular  => q{is_singular: 'synesthesia'};
ok noun(q{clostridium})->is_singular  => q{is_singular: 'clostridium'};
ok noun(q{psydracium})->is_singular  => q{is_singular: 'psydracium'};
ok noun(q{who})->is_singular  => q{is_singular: 'who'};
ok noun(q{aphis})->is_singular  => q{is_singular: 'aphis'};
ok noun(q{bathos})->is_singular  => q{is_singular: 'bathos'};
ok noun(q{Colorado})->is_singular  => q{is_singular: 'Colorado'};
ok noun(q{terebratula})->is_singular  => q{is_singular: 'terebratula'};
ok noun(q{tuberculum})->is_singular  => q{is_singular: 'tuberculum'};
ok noun(q{trachea})->is_singular  => q{is_singular: 'trachea'};
ok noun(q{asylum})->is_singular  => q{is_singular: 'asylum'};
ok noun(q{gallows})->is_singular  => q{is_singular: 'gallows'};
ok noun(q{prolabium})->is_singular  => q{is_singular: 'prolabium'};
ok noun(q{flocculus})->is_singular  => q{is_singular: 'flocculus'};
ok noun(q{jeu})->is_singular  => q{is_singular: 'jeu'};
ok noun(q{whiting})->is_singular  => q{is_singular: 'whiting'};
ok noun(q{coccidium})->is_singular  => q{is_singular: 'coccidium'};
ok noun(q{route nationale})->is_singular  => q{is_singular: 'route nationale'};
ok noun(q{inferno})->is_singular  => q{is_singular: 'inferno'};
ok noun(q{glomus})->is_singular  => q{is_singular: 'glomus'};
ok noun(q{spondylus})->is_singular  => q{is_singular: 'spondylus'};
ok noun(q{bozzetto})->is_singular  => q{is_singular: 'bozzetto'};
ok noun(q{rabies})->is_singular  => q{is_singular: 'rabies'};
ok noun(q{set-off})->is_singular  => q{is_singular: 'set-off'};
ok noun(q{sotch})->is_singular  => q{is_singular: 'sotch'};
ok noun(q{vitta})->is_singular  => q{is_singular: 'vitta'};
ok noun(q{rezidentsia})->is_singular  => q{is_singular: 'rezidentsia'};
ok noun(q{schizostylis})->is_singular  => q{is_singular: 'schizostylis'};
ok noun(q{bhikshu})->is_singular  => q{is_singular: 'bhikshu'};
ok noun(q{erratum})->is_singular  => q{is_singular: 'erratum'};
ok noun(q{cyathus})->is_singular  => q{is_singular: 'cyathus'};
ok noun(q{britches})->is_singular  => q{is_singular: 'britches'};
ok noun(q{intermedium})->is_singular  => q{is_singular: 'intermedium'};
ok noun(q{auto-de-fe})->is_singular  => q{is_singular: 'auto-de-fe'};
ok noun(q{cecidium})->is_singular  => q{is_singular: 'cecidium'};
ok noun(q{solenium})->is_singular  => q{is_singular: 'solenium'};
ok noun(q{inukshuk})->is_singular  => q{is_singular: 'inukshuk'};
ok noun(q{umwelt})->is_singular  => q{is_singular: 'umwelt'};
ok noun(q{magilus})->is_singular  => q{is_singular: 'magilus'};
ok noun(q{divertimento})->is_singular  => q{is_singular: 'divertimento'};
ok noun(q{regulus})->is_singular  => q{is_singular: 'regulus'};
ok noun(q{scirrhus})->is_singular  => q{is_singular: 'scirrhus'};
ok noun(q{flounder})->is_singular  => q{is_singular: 'flounder'};
ok noun(q{karrenfeld})->is_singular  => q{is_singular: 'karrenfeld'};
ok noun(q{gladiolus})->is_singular  => q{is_singular: 'gladiolus'};
ok noun(q{reductio})->is_singular  => q{is_singular: 'reductio'};
ok noun(q{rezident})->is_singular  => q{is_singular: 'rezident'};
ok noun(q{mo})->is_singular  => q{is_singular: 'mo'};
ok noun(q{leu})->is_singular  => q{is_singular: 'leu'};
ok noun(q{pied a terre})->is_singular  => q{is_singular: 'pied a terre'};
ok noun(q{herpes})->is_singular  => q{is_singular: 'herpes'};
ok noun(q{evirato})->is_singular  => q{is_singular: 'evirato'};
ok noun(q{isidium})->is_singular  => q{is_singular: 'isidium'};
ok noun(q{graben})->is_singular  => q{is_singular: 'graben'};
ok noun(q{opus})->is_singular  => q{is_singular: 'opus'};
ok noun(q{kobo})->is_singular  => q{is_singular: 'kobo'};
ok noun(q{yoe})->is_singular  => q{is_singular: 'yoe'};
ok noun(q{staretz})->is_singular  => q{is_singular: 'staretz'};
ok noun(q{septarium})->is_singular  => q{is_singular: 'septarium'};
ok noun(q{limax})->is_singular  => q{is_singular: 'limax'};
ok noun(q{talisman})->is_singular  => q{is_singular: 'talisman'};
ok noun(q{gens})->is_singular  => q{is_singular: 'gens'};
ok noun(q{armadillo})->is_singular  => q{is_singular: 'armadillo'};
ok noun(q{canto})->is_singular  => q{is_singular: 'canto'};
ok noun(q{mortadella})->is_singular  => q{is_singular: 'mortadella'};
ok noun(q{stolo})->is_singular  => q{is_singular: 'stolo'};
ok noun(q{uredium})->is_singular  => q{is_singular: 'uredium'};
ok noun(q{Kiplingese})->is_singular  => q{is_singular: 'Kiplingese'};
ok noun(q{feis})->is_singular  => q{is_singular: 'feis'};
ok noun(q{lentigo})->is_singular  => q{is_singular: 'lentigo'};
ok noun(q{tuna})->is_singular  => q{is_singular: 'tuna'};
ok noun(q{prepenna})->is_singular  => q{is_singular: 'prepenna'};
ok noun(q{albergo})->is_singular  => q{is_singular: 'albergo'};
ok noun(q{nidus})->is_singular  => q{is_singular: 'nidus'};
ok noun(q{Toronto})->is_singular  => q{is_singular: 'Toronto'};
ok noun(q{tableau})->is_singular  => q{is_singular: 'tableau'};
ok noun(q{isthmus})->is_singular  => q{is_singular: 'isthmus'};
ok noun(q{syphiloma})->is_singular  => q{is_singular: 'syphiloma'};
ok noun(q{Bolzano})->is_singular  => q{is_singular: 'Bolzano'};
ok noun(q{rubashka})->is_singular  => q{is_singular: 'rubashka'};
ok noun(q{maecenas})->is_singular  => q{is_singular: 'maecenas'};
ok noun(q{protoma})->is_singular  => q{is_singular: 'protoma'};
ok noun(q{aboiteau})->is_singular  => q{is_singular: 'aboiteau'};
ok noun(q{eunuch})->is_singular  => q{is_singular: 'eunuch'};
ok noun(q{Camaldolese})->is_singular  => q{is_singular: 'Camaldolese'};
ok noun(q{convolvulus})->is_singular  => q{is_singular: 'convolvulus'};
ok noun(q{vila})->is_singular  => q{is_singular: 'vila'};
ok noun(q{wolf})->is_singular  => q{is_singular: 'wolf'};
ok noun(q{adminiculum})->is_singular  => q{is_singular: 'adminiculum'};
ok noun(q{meshumad})->is_singular  => q{is_singular: 'meshumad'};
ok noun(q{sombrero})->is_singular  => q{is_singular: 'sombrero'};
ok noun(q{Muqdisho})->is_singular  => q{is_singular: 'Muqdisho'};
ok noun(q{Atlas})->is_singular  => q{is_singular: 'Atlas'};
ok noun(q{pediluvium})->is_singular  => q{is_singular: 'pediluvium'};
ok noun(q{axopodium})->is_singular  => q{is_singular: 'axopodium'};
ok noun(q{ho})->is_singular  => q{is_singular: 'ho'};
ok noun(q{loggia})->is_singular  => q{is_singular: 'loggia'};
ok noun(q{parapleurum})->is_singular  => q{is_singular: 'parapleurum'};
ok noun(q{cantus})->is_singular  => q{is_singular: 'cantus'};
ok noun(q{internodium})->is_singular  => q{is_singular: 'internodium'};
ok noun(q{torulus})->is_singular  => q{is_singular: 'torulus'};
ok noun(q{crista})->is_singular  => q{is_singular: 'crista'};
ok noun(q{poe})->is_singular  => q{is_singular: 'poe'};
ok noun(q{pectus})->is_singular  => q{is_singular: 'pectus'};
ok noun(q{cod})->is_singular  => q{is_singular: 'cod'};
ok noun(q{sinfonia})->is_singular  => q{is_singular: 'sinfonia'};
ok noun(q{razz})->is_singular  => q{is_singular: 'razz'};
ok noun(q{imago})->is_singular  => q{is_singular: 'imago'};
ok noun(q{infima species})->is_singular  => q{is_singular: 'infima species'};
ok noun(q{caecum})->is_singular  => q{is_singular: 'caecum'};
ok noun(q{poculum})->is_singular  => q{is_singular: 'poculum'};
ok noun(q{monota})->is_singular  => q{is_singular: 'monota'};
ok noun(q{ostium})->is_singular  => q{is_singular: 'ostium'};
ok noun(q{bijou})->is_singular  => q{is_singular: 'bijou'};
ok noun(q{craft})->is_singular  => q{is_singular: 'craft'};
ok noun(q{pifferaro})->is_singular  => q{is_singular: 'pifferaro'};
ok noun(q{epithelioma})->is_singular  => q{is_singular: 'epithelioma'};
ok noun(q{tsubo})->is_singular  => q{is_singular: 'tsubo'};
ok noun(q{ale wife})->is_singular  => q{is_singular: 'ale wife'};
ok noun(q{linctus})->is_singular  => q{is_singular: 'linctus'};
ok noun(q{soe})->is_singular  => q{is_singular: 'soe'};
ok noun(q{dumka})->is_singular  => q{is_singular: 'dumka'};
ok noun(q{prora})->is_singular  => q{is_singular: 'prora'};
ok noun(q{improvisatrice})->is_singular  => q{is_singular: 'improvisatrice'};
ok noun(q{seminium})->is_singular  => q{is_singular: 'seminium'};
ok noun(q{court-martial})->is_singular  => q{is_singular: 'court-martial'};
ok noun(q{terebellum})->is_singular  => q{is_singular: 'terebellum'};
ok noun(q{veg})->is_singular  => q{is_singular: 'veg'};
ok noun(q{asbestos})->is_singular  => q{is_singular: 'asbestos'};
ok noun(q{quadratrix})->is_singular  => q{is_singular: 'quadratrix'};
ok noun(q{him})->is_singular  => q{is_singular: 'him'};
ok noun(q{aquarium})->is_singular  => q{is_singular: 'aquarium'};
ok noun(q{Lucchese})->is_singular  => q{is_singular: 'Lucchese'};
ok noun(q{sperma})->is_singular  => q{is_singular: 'sperma'};
ok noun(q{taxon})->is_singular  => q{is_singular: 'taxon'};
ok noun(q{tortilla espanola})->is_singular  => q{is_singular: 'tortilla espanola'};
ok noun(q{uraeus})->is_singular  => q{is_singular: 'uraeus'};
ok noun(q{gastrocnemius})->is_singular  => q{is_singular: 'gastrocnemius'};
ok noun(q{Hunanese})->is_singular  => q{is_singular: 'Hunanese'};
ok noun(q{premier danseur})->is_singular  => q{is_singular: 'premier danseur'};
ok noun(q{chintz})->is_singular  => q{is_singular: 'chintz'};
ok noun(q{paisa})->is_singular  => q{is_singular: 'paisa'};
ok noun(q{parapsis})->is_singular  => q{is_singular: 'parapsis'};
ok noun(q{hemelytrum})->is_singular  => q{is_singular: 'hemelytrum'};
ok noun(q{bison})->is_singular  => q{is_singular: 'bison'};
ok noun(q{furfur})->is_singular  => q{is_singular: 'furfur'};
ok noun(q{crusta})->is_singular  => q{is_singular: 'crusta'};
ok noun(q{pinetum})->is_singular  => q{is_singular: 'pinetum'};
ok noun(q{endothelioma})->is_singular  => q{is_singular: 'endothelioma'};
ok noun(q{sternum})->is_singular  => q{is_singular: 'sternum'};
ok noun(q{thaumaturgus})->is_singular  => q{is_singular: 'thaumaturgus'};
ok noun(q{tyro})->is_singular  => q{is_singular: 'tyro'};
ok noun(q{mucro})->is_singular  => q{is_singular: 'mucro'};
ok noun(q{villino})->is_singular  => q{is_singular: 'villino'};
ok noun(q{temblor})->is_singular  => q{is_singular: 'temblor'};
ok noun(q{commanding general})->is_singular  => q{is_singular: 'commanding general'};
ok noun(q{Oslo})->is_singular  => q{is_singular: 'Oslo'};
ok noun(q{treponema})->is_singular  => q{is_singular: 'treponema'};
ok noun(q{redia})->is_singular  => q{is_singular: 'redia'};
ok noun(q{potato})->is_singular  => q{is_singular: 'potato'};
ok noun(q{talea})->is_singular  => q{is_singular: 'talea'};
ok noun(q{nouvel arrive})->is_singular  => q{is_singular: 'nouvel arrive'};
ok noun(q{stratum})->is_singular  => q{is_singular: 'stratum'};
ok noun(q{spiculum})->is_singular  => q{is_singular: 'spiculum'};
ok noun(q{whatever})->is_singular  => q{is_singular: 'whatever'};
ok noun(q{podium})->is_singular  => q{is_singular: 'podium'};
ok noun(q{thalamos})->is_singular  => q{is_singular: 'thalamos'};
ok noun(q{anlage})->is_singular  => q{is_singular: 'anlage'};
ok noun(q{chromidium})->is_singular  => q{is_singular: 'chromidium'};
ok noun(q{prosopium})->is_singular  => q{is_singular: 'prosopium'};
ok noun(q{columna})->is_singular  => q{is_singular: 'columna'};
ok noun(q{frustum})->is_singular  => q{is_singular: 'frustum'};
ok noun(q{crafts-child})->is_singular  => q{is_singular: 'crafts-child'};
ok noun(q{dolman})->is_singular  => q{is_singular: 'dolman'};
ok noun(q{humerus})->is_singular  => q{is_singular: 'humerus'};
ok noun(q{amicus curiae})->is_singular  => q{is_singular: 'amicus curiae'};
ok noun(q{hypoderma})->is_singular  => q{is_singular: 'hypoderma'};
ok noun(q{tropaeolum})->is_singular  => q{is_singular: 'tropaeolum'};
ok noun(q{star fish})->is_singular  => q{is_singular: 'star fish'};
ok noun(q{tetrapleuron})->is_singular  => q{is_singular: 'tetrapleuron'};
ok noun(q{Senegalese})->is_singular  => q{is_singular: 'Senegalese'};
ok noun(q{neuroma})->is_singular  => q{is_singular: 'neuroma'};
ok noun(q{fungo porcino})->is_singular  => q{is_singular: 'fungo porcino'};
ok noun(q{uredosorus})->is_singular  => q{is_singular: 'uredosorus'};
ok noun(q{syrtis})->is_singular  => q{is_singular: 'syrtis'};
ok noun(q{centesimo})->is_singular  => q{is_singular: 'centesimo'};
ok noun(q{cyphella})->is_singular  => q{is_singular: 'cyphella'};
ok noun(q{branchiopod})->is_singular  => q{is_singular: 'branchiopod'};
ok noun(q{foot})->is_singular  => q{is_singular: 'foot'};
ok noun(q{tarsus})->is_singular  => q{is_singular: 'tarsus'};
ok noun(q{holothuria})->is_singular  => q{is_singular: 'holothuria'};
ok noun(q{Shavese})->is_singular  => q{is_singular: 'Shavese'};
ok noun(q{lepton})->is_singular  => q{is_singular: 'lepton'};
ok noun(q{yourself})->is_singular  => q{is_singular: 'yourself'};
ok noun(q{Rom})->is_singular  => q{is_singular: 'Rom'};
ok noun(q{adviso})->is_singular  => q{is_singular: 'adviso'};
ok noun(q{proprium})->is_singular  => q{is_singular: 'proprium'};
ok noun(q{moe})->is_singular  => q{is_singular: 'moe'};
ok noun(q{cardo})->is_singular  => q{is_singular: 'cardo'};
ok noun(q{terrazzo})->is_singular  => q{is_singular: 'terrazzo'};
ok noun(q{ossiculum})->is_singular  => q{is_singular: 'ossiculum'};
ok noun(q{Sangirese})->is_singular  => q{is_singular: 'Sangirese'};
ok noun(q{fomes})->is_singular  => q{is_singular: 'fomes'};
ok noun(q{you})->is_singular  => q{is_singular: 'you'};
ok noun(q{pickerel})->is_singular  => q{is_singular: 'pickerel'};
ok noun(q{piano})->is_singular  => q{is_singular: 'piano'};
ok noun(q{1 star general})->is_singular  => q{is_singular: '1 star general'};
ok noun(q{sulcus})->is_singular  => q{is_singular: 'sulcus'};
ok noun(q{Porto})->is_singular  => q{is_singular: 'Porto'};
ok noun(q{ghetto})->is_singular  => q{is_singular: 'ghetto'};
ok noun(q{corgy})->is_singular  => q{is_singular: 'corgy'};
ok noun(q{Siamese})->is_singular  => q{is_singular: 'Siamese'};
ok noun(q{superficies})->is_singular  => q{is_singular: 'superficies'};
ok noun(q{emblema})->is_singular  => q{is_singular: 'emblema'};
ok noun(q{multigravida})->is_singular  => q{is_singular: 'multigravida'};
ok noun(q{angustia})->is_singular  => q{is_singular: 'angustia'};
ok noun(q{sphinx})->is_singular  => q{is_singular: 'sphinx'};
ok noun(q{themselves})->is_singular  => q{is_singular: 'themselves'};
ok noun(q{nouveau riche})->is_singular  => q{is_singular: 'nouveau riche'};
ok noun(q{proglottis})->is_singular  => q{is_singular: 'proglottis'};
ok noun(q{sensum})->is_singular  => q{is_singular: 'sensum'};
ok noun(q{congius})->is_singular  => q{is_singular: 'congius'};
ok noun(q{yo})->is_singular  => q{is_singular: 'yo'};
ok noun(q{nodum})->is_singular  => q{is_singular: 'nodum'};
ok noun(q{this})->is_singular  => q{is_singular: 'this'};
ok noun(q{lox})->is_singular  => q{is_singular: 'lox'};
ok noun(q{tibia})->is_singular  => q{is_singular: 'tibia'};
ok noun(q{Bengalese})->is_singular  => q{is_singular: 'Bengalese'};
ok noun(q{caulis})->is_singular  => q{is_singular: 'caulis'};
ok noun(q{seraph})->is_singular  => q{is_singular: 'seraph'};
ok noun(q{Pekingese})->is_singular  => q{is_singular: 'Pekingese'};
ok noun(q{blin})->is_singular  => q{is_singular: 'blin'};
ok noun(q{chorda})->is_singular  => q{is_singular: 'chorda'};
ok noun(q{speculum})->is_singular  => q{is_singular: 'speculum'};
ok noun(q{protonema})->is_singular  => q{is_singular: 'protonema'};
ok noun(q{codex})->is_singular  => q{is_singular: 'codex'};
ok noun(q{line-out})->is_singular  => q{is_singular: 'line-out'};
ok noun(q{purlieu})->is_singular  => q{is_singular: 'purlieu'};
ok noun(q{virtuoso})->is_singular  => q{is_singular: 'virtuoso'};
ok noun(q{minnelied})->is_singular  => q{is_singular: 'minnelied'};
ok noun(q{graffito})->is_singular  => q{is_singular: 'graffito'};
ok noun(q{prosula})->is_singular  => q{is_singular: 'prosula'};
ok noun(q{Kinkimavo})->is_singular  => q{is_singular: 'Kinkimavo'};
ok noun(q{breeches})->is_singular  => q{is_singular: 'breeches'};
ok noun(q{interphenomenon})->is_singular  => q{is_singular: 'interphenomenon'};
ok noun(q{teredo})->is_singular  => q{is_singular: 'teredo'};
ok noun(q{hoe})->is_singular  => q{is_singular: 'hoe'};
ok noun(q{tentamen})->is_singular  => q{is_singular: 'tentamen'};
ok noun(q{pyjamas})->is_singular  => q{is_singular: 'pyjamas'};
ok noun(q{persona})->is_singular  => q{is_singular: 'persona'};
ok noun(q{jumbo})->is_singular  => q{is_singular: 'jumbo'};
ok noun(q{proviso})->is_singular  => q{is_singular: 'proviso'};
ok noun(q{trichoma})->is_singular  => q{is_singular: 'trichoma'};
ok noun(q{person})->is_singular  => q{is_singular: 'person'};
ok noun(q{sententia})->is_singular  => q{is_singular: 'sententia'};
ok noun(q{carp})->is_singular  => q{is_singular: 'carp'};
ok noun(q{po})->is_singular  => q{is_singular: 'po'};
ok noun(q{hordeolum})->is_singular  => q{is_singular: 'hordeolum'};
ok noun(q{lustrum})->is_singular  => q{is_singular: 'lustrum'};
ok noun(q{stela})->is_singular  => q{is_singular: 'stela'};
ok noun(q{torula})->is_singular  => q{is_singular: 'torula'};
ok noun(q{stella})->is_singular  => q{is_singular: 'stella'};
ok noun(q{suggestum})->is_singular  => q{is_singular: 'suggestum'};
ok noun(q{sterno})->is_singular  => q{is_singular: 'sterno'};
ok noun(q{gliosarcoma})->is_singular  => q{is_singular: 'gliosarcoma'};
ok noun(q{Sienese})->is_singular  => q{is_singular: 'Sienese'};
ok noun(q{zygon})->is_singular  => q{is_singular: 'zygon'};
ok noun(q{Foochowese})->is_singular  => q{is_singular: 'Foochowese'};
ok noun(q{pteryla})->is_singular  => q{is_singular: 'pteryla'};
ok noun(q{gigolo})->is_singular  => q{is_singular: 'gigolo'};
ok noun(q{one star general})->is_singular  => q{is_singular: 'one star general'};
ok noun(q{ado})->is_singular  => q{is_singular: 'ado'};
ok noun(q{stadium})->is_singular  => q{is_singular: 'stadium'};
ok noun(q{stichidium})->is_singular  => q{is_singular: 'stichidium'};
ok noun(q{lemur})->is_singular  => q{is_singular: 'lemur'};
ok noun(q{so})->is_singular  => q{is_singular: 'so'};
ok noun(q{nebula})->is_singular  => q{is_singular: 'nebula'};
ok noun(q{palpus})->is_singular  => q{is_singular: 'palpus'};
ok noun(q{cyano})->is_singular  => q{is_singular: 'cyano'};
ok noun(q{ambuscado})->is_singular  => q{is_singular: 'ambuscado'};
ok noun(q{vibrio})->is_singular  => q{is_singular: 'vibrio'};
ok noun(q{stamen})->is_singular  => q{is_singular: 'stamen'};
ok noun(q{strobilus})->is_singular  => q{is_singular: 'strobilus'};
ok noun(q{go})->is_singular  => q{is_singular: 'go'};
ok noun(q{mixolimnion})->is_singular  => q{is_singular: 'mixolimnion'};
ok noun(q{cognoscente})->is_singular  => q{is_singular: 'cognoscente'};
ok noun(q{radiale})->is_singular  => q{is_singular: 'radiale'};
ok noun(q{meningioma})->is_singular  => q{is_singular: 'meningioma'};
ok noun(q{nachtlokal})->is_singular  => q{is_singular: 'nachtlokal'};
ok noun(q{ramus})->is_singular  => q{is_singular: 'ramus'};
ok noun(q{gymnotus})->is_singular  => q{is_singular: 'gymnotus'};
ok noun(q{caribou})->is_singular  => q{is_singular: 'caribou'};
ok noun(q{antiserum})->is_singular  => q{is_singular: 'antiserum'};
ok noun(q{cherub})->is_singular  => q{is_singular: 'cherub'};
ok noun(q{braccio})->is_singular  => q{is_singular: 'braccio'};
ok noun(q{amoeba})->is_singular  => q{is_singular: 'amoeba'};
ok noun(q{manubrium})->is_singular  => q{is_singular: 'manubrium'};
ok noun(q{didymis})->is_singular  => q{is_singular: 'didymis'};
ok noun(q{cayman})->is_singular  => q{is_singular: 'cayman'};
ok noun(q{Panaman})->is_singular  => q{is_singular: 'Panaman'};
ok noun(q{measles})->is_singular  => q{is_singular: 'measles'};
ok noun(q{confluvium})->is_singular  => q{is_singular: 'confluvium'};
ok noun(q{nimbus})->is_singular  => q{is_singular: 'nimbus'};
ok noun(q{optimum})->is_singular  => q{is_singular: 'optimum'};
ok noun(q{satelles})->is_singular  => q{is_singular: 'satelles'};
ok noun(q{micrococcus})->is_singular  => q{is_singular: 'micrococcus'};
ok noun(q{kilo})->is_singular  => q{is_singular: 'kilo'};
ok noun(q{sequestrum})->is_singular  => q{is_singular: 'sequestrum'};
ok noun(q{Togo})->is_singular  => q{is_singular: 'Togo'};
ok noun(q{salpa})->is_singular  => q{is_singular: 'salpa'};
ok noun(q{prytanis})->is_singular  => q{is_singular: 'prytanis'};
ok noun(q{dolphinarium})->is_singular  => q{is_singular: 'dolphinarium'};
ok noun(q{verruca})->is_singular  => q{is_singular: 'verruca'};
ok noun(q{apparatchik})->is_singular  => q{is_singular: 'apparatchik'};
ok noun(q{trumeau})->is_singular  => q{is_singular: 'trumeau'};
ok noun(q{uva})->is_singular  => q{is_singular: 'uva'};
ok noun(q{math})->is_singular  => q{is_singular: 'math'};
ok noun(q{sandr})->is_singular  => q{is_singular: 'sandr'};
ok noun(q{conferva})->is_singular  => q{is_singular: 'conferva'};
ok noun(q{hemangeioma})->is_singular  => q{is_singular: 'hemangeioma'};
ok noun(q{aelf})->is_singular  => q{is_singular: 'aelf'};
ok noun(q{granita})->is_singular  => q{is_singular: 'granita'};
ok noun(q{myself})->is_singular  => q{is_singular: 'myself'};
ok noun(q{cyclops})->is_singular  => q{is_singular: 'cyclops'};
ok noun(q{paraglossa})->is_singular  => q{is_singular: 'paraglossa'};
ok noun(q{four-star general})->is_singular  => q{is_singular: 'four-star general'};
ok noun(q{monosyllabon})->is_singular  => q{is_singular: 'monosyllabon'};
ok noun(q{gaon})->is_singular  => q{is_singular: 'gaon'};
ok noun(q{pseudostoma})->is_singular  => q{is_singular: 'pseudostoma'};
ok noun(q{autostrada})->is_singular  => q{is_singular: 'autostrada'};
ok noun(q{Maracaibo})->is_singular  => q{is_singular: 'Maracaibo'};
ok noun(q{shaman})->is_singular  => q{is_singular: 'shaman'};
ok noun(q{zooea})->is_singular  => q{is_singular: 'zooea'};
ok noun(q{Nankingese})->is_singular  => q{is_singular: 'Nankingese'};
ok noun(q{zemirah})->is_singular  => q{is_singular: 'zemirah'};
ok noun(q{lino})->is_singular  => q{is_singular: 'lino'};
ok noun(q{taxis})->is_singular  => q{is_singular: 'taxis'};
ok noun(q{sertularia})->is_singular  => q{is_singular: 'sertularia'};
ok noun(q{Genoese})->is_singular  => q{is_singular: 'Genoese'};
ok noun(q{principium})->is_singular  => q{is_singular: 'principium'};
ok noun(q{Goanese})->is_singular  => q{is_singular: 'Goanese'};
ok noun(q{tooth})->is_singular  => q{is_singular: 'tooth'};
ok noun(q{lebensform})->is_singular  => q{is_singular: 'lebensform'};
ok noun(q{xystus})->is_singular  => q{is_singular: 'xystus'};
ok noun(q{orthoceras})->is_singular  => q{is_singular: 'orthoceras'};
ok noun(q{scandalum magnatum})->is_singular  => q{is_singular: 'scandalum magnatum'};
ok noun(q{risotto})->is_singular  => q{is_singular: 'risotto'};
ok noun(q{pithos})->is_singular  => q{is_singular: 'pithos'};
ok noun(q{organon})->is_singular  => q{is_singular: 'organon'};
ok noun(q{listeria})->is_singular  => q{is_singular: 'listeria'};
ok noun(q{syllabus})->is_singular  => q{is_singular: 'syllabus'};
ok noun(q{clitoris})->is_singular  => q{is_singular: 'clitoris'};
ok noun(q{ ox})->is_singular  => q{is_singular: ' ox'};
ok noun(q{sum total})->is_singular  => q{is_singular: 'sum total'};
ok noun(q{promerops})->is_singular  => q{is_singular: 'promerops'};
ok noun(q{piscina})->is_singular  => q{is_singular: 'piscina'};
ok noun(q{squilla})->is_singular  => q{is_singular: 'squilla'};
ok noun(q{pteroma})->is_singular  => q{is_singular: 'pteroma'};
ok noun(q{vallecula})->is_singular  => q{is_singular: 'vallecula'};
ok noun(q{macacus})->is_singular  => q{is_singular: 'macacus'};
ok noun(q{tuberculoma})->is_singular  => q{is_singular: 'tuberculoma'};
ok noun(q{stigmaria})->is_singular  => q{is_singular: 'stigmaria'};
ok noun(q{Czech})->is_singular  => q{is_singular: 'Czech'};
ok noun(q{hijinks})->is_singular  => q{is_singular: 'hijinks'};
ok noun(q{syrinx})->is_singular  => q{is_singular: 'syrinx'};
ok noun(q{frizz})->is_singular  => q{is_singular: 'frizz'};
ok noun(q{monsignor})->is_singular  => q{is_singular: 'monsignor'};
ok noun(q{pike})->is_singular  => q{is_singular: 'pike'};
ok noun(q{capo})->is_singular  => q{is_singular: 'capo'};
ok noun(q{sinus})->is_singular  => q{is_singular: 'sinus'};
ok noun(q{lymphangioma})->is_singular  => q{is_singular: 'lymphangioma'};
ok noun(q{gena})->is_singular  => q{is_singular: 'gena'};
ok noun(q{stomatium})->is_singular  => q{is_singular: 'stomatium'};
ok noun(q{cornu})->is_singular  => q{is_singular: 'cornu'};
ok noun(q{jazz})->is_singular  => q{is_singular: 'jazz'};
ok noun(q{sphaeridium})->is_singular  => q{is_singular: 'sphaeridium'};
ok noun(q{synusia})->is_singular  => q{is_singular: 'synusia'};
ok noun(q{scungille})->is_singular  => q{is_singular: 'scungille'};
ok noun(q{malleolus})->is_singular  => q{is_singular: 'malleolus'};
ok noun(q{crowfoot})->is_singular  => q{is_singular: 'crowfoot'};
ok noun(q{pyla})->is_singular  => q{is_singular: 'pyla'};
ok noun(q{sis})->is_singular  => q{is_singular: 'sis'};
ok noun(q{sacculus})->is_singular  => q{is_singular: 'sacculus'};
ok noun(q{fait accompli})->is_singular  => q{is_singular: 'fait accompli'};
ok noun(q{hedron})->is_singular  => q{is_singular: 'hedron'};
ok noun(q{stucco})->is_singular  => q{is_singular: 'stucco'};
ok noun(q{loculus})->is_singular  => q{is_singular: 'loculus'};
ok noun(q{papilloma})->is_singular  => q{is_singular: 'papilloma'};
ok noun(q{poncho})->is_singular  => q{is_singular: 'poncho'};
ok noun(q{caudex})->is_singular  => q{is_singular: 'caudex'};
ok noun(q{solstitium})->is_singular  => q{is_singular: 'solstitium'};
ok noun(q{axilla})->is_singular  => q{is_singular: 'axilla'};
ok noun(q{tomium})->is_singular  => q{is_singular: 'tomium'};
ok noun(q{descriptum})->is_singular  => q{is_singular: 'descriptum'};
ok noun(q{tondo})->is_singular  => q{is_singular: 'tondo'};
ok noun(q{ulpan})->is_singular  => q{is_singular: 'ulpan'};
ok noun(q{precognitum})->is_singular  => q{is_singular: 'precognitum'};
ok noun(q{bon vivant})->is_singular  => q{is_singular: 'bon vivant'};
ok noun(q{sestertium})->is_singular  => q{is_singular: 'sestertium'};
ok noun(q{fanfoot})->is_singular  => q{is_singular: 'fanfoot'};
ok noun(q{medusa})->is_singular  => q{is_singular: 'medusa'};
ok noun(q{suprascapula})->is_singular  => q{is_singular: 'suprascapula'};
ok noun(q{life})->is_singular  => q{is_singular: 'life'};
ok noun(q{Porto-Novo})->is_singular  => q{is_singular: 'Porto-Novo'};
ok noun(q{uncinus})->is_singular  => q{is_singular: 'uncinus'};
ok noun(q{sacellum})->is_singular  => q{is_singular: 'sacellum'};
ok noun(q{cleithrum})->is_singular  => q{is_singular: 'cleithrum'};
ok noun(q{conidium})->is_singular  => q{is_singular: 'conidium'};
ok noun(q{squadrist})->is_singular  => q{is_singular: 'squadrist'};
ok noun(q{strambotto})->is_singular  => q{is_singular: 'strambotto'};
ok noun(q{ogle})->is_singular  => q{is_singular: 'ogle'};
ok noun(q{fauna})->is_singular  => q{is_singular: 'fauna'};
ok noun(q{axe})->is_singular  => q{is_singular: 'axe'};
ok noun(q{macula})->is_singular  => q{is_singular: 'macula'};
ok noun(q{bordereau})->is_singular  => q{is_singular: 'bordereau'};
ok noun(q{Bolognese})->is_singular  => q{is_singular: 'Bolognese'};
ok noun(q{hemi elytrum})->is_singular  => q{is_singular: 'hemi elytrum'};
ok noun(q{voorbok})->is_singular  => q{is_singular: 'voorbok'};
ok noun(q{two-star general})->is_singular  => q{is_singular: 'two-star general'};
ok noun(q{non ens})->is_singular  => q{is_singular: 'non ens'};
ok noun(q{vermiculus})->is_singular  => q{is_singular: 'vermiculus'};
ok noun(q{sphex})->is_singular  => q{is_singular: 'sphex'};
ok noun(q{ischium})->is_singular  => q{is_singular: 'ischium'};
ok noun(q{camera obscura})->is_singular  => q{is_singular: 'camera obscura'};
ok noun(q{felo})->is_singular  => q{is_singular: 'felo'};
ok noun(q{ex})->is_singular  => q{is_singular: 'ex'};
ok noun(q{prokaryon})->is_singular  => q{is_singular: 'prokaryon'};
ok noun(q{typo})->is_singular  => q{is_singular: 'typo'};
ok noun(q{Assamese})->is_singular  => q{is_singular: 'Assamese'};
ok noun(q{alto relievo})->is_singular  => q{is_singular: 'alto relievo'};
ok noun(q{break away})->is_singular  => q{is_singular: 'break away'};
ok noun(q{vertex})->is_singular  => q{is_singular: 'vertex'};
ok noun(q{minimum})->is_singular  => q{is_singular: 'minimum'};
ok noun(q{Chinese})->is_singular  => q{is_singular: 'Chinese'};
ok noun(q{oath})->is_singular  => q{is_singular: 'oath'};
ok noun(q{Burmese})->is_singular  => q{is_singular: 'Burmese'};
ok noun(q{Achinese})->is_singular  => q{is_singular: 'Achinese'};
ok noun(q{postpubis})->is_singular  => q{is_singular: 'postpubis'};
ok noun(q{Maltese})->is_singular  => q{is_singular: 'Maltese'};
ok noun(q{halibut})->is_singular  => q{is_singular: 'halibut'};
ok noun(q{man-milliner})->is_singular  => q{is_singular: 'man-milliner'};
ok noun(q{myeloma})->is_singular  => q{is_singular: 'myeloma'};
ok noun(q{path})->is_singular  => q{is_singular: 'path'};
ok noun(q{streptococcus})->is_singular  => q{is_singular: 'streptococcus'};
ok noun(q{Bernese})->is_singular  => q{is_singular: 'Bernese'};
ok noun(q{Asherah})->is_singular  => q{is_singular: 'Asherah'};
ok noun(q{mya})->is_singular  => q{is_singular: 'mya'};
ok noun(q{zoarium})->is_singular  => q{is_singular: 'zoarium'};
ok noun(q{fecula})->is_singular  => q{is_singular: 'fecula'};
ok noun(q{acicula})->is_singular  => q{is_singular: 'acicula'};
ok noun(q{pul})->is_singular  => q{is_singular: 'pul'};
ok noun(q{Genevese})->is_singular  => q{is_singular: 'Genevese'};
ok noun(q{cystidium})->is_singular  => q{is_singular: 'cystidium'};
ok noun(q{miracidium})->is_singular  => q{is_singular: 'miracidium'};
ok noun(q{agon})->is_singular  => q{is_singular: 'agon'};
ok noun(q{bolero})->is_singular  => q{is_singular: 'bolero'};
ok noun(q{scomber})->is_singular  => q{is_singular: 'scomber'};
ok noun(q{cranium})->is_singular  => q{is_singular: 'cranium'};
ok noun(q{secretum})->is_singular  => q{is_singular: 'secretum'};
ok noun(q{schisma})->is_singular  => q{is_singular: 'schisma'};
ok noun(q{flag-staff})->is_singular  => q{is_singular: 'flag-staff'};
ok noun(q{tractellum})->is_singular  => q{is_singular: 'tractellum'};
ok noun(q{3-star general})->is_singular  => q{is_singular: '3-star general'};
ok noun(q{guardia civil})->is_singular  => q{is_singular: 'guardia civil'};
ok noun(q{Lapith})->is_singular  => q{is_singular: 'Lapith'};
ok noun(q{cultellus})->is_singular  => q{is_singular: 'cultellus'};
ok noun(q{sarcophagus})->is_singular  => q{is_singular: 'sarcophagus'};
ok noun(q{vaquero})->is_singular  => q{is_singular: 'vaquero'};
ok noun(q{milieu})->is_singular  => q{is_singular: 'milieu'};
ok noun(q{idee fixe})->is_singular  => q{is_singular: 'idee fixe'};
ok noun(q{silex})->is_singular  => q{is_singular: 'silex'};
ok noun(q{pupa})->is_singular  => q{is_singular: 'pupa'};
ok noun(q{cri de coeur})->is_singular  => q{is_singular: 'cri de coeur'};
ok noun(q{spermatoon})->is_singular  => q{is_singular: 'spermatoon'};
ok noun(q{lactobacillus})->is_singular  => q{is_singular: 'lactobacillus'};
ok noun(q{cuniculus})->is_singular  => q{is_singular: 'cuniculus'};
ok noun(q{rhythmus})->is_singular  => q{is_singular: 'rhythmus'};
ok noun(q{rondeau})->is_singular  => q{is_singular: 'rondeau'};
ok noun(q{lineno})->is_singular  => q{is_singular: 'lineno'};
ok noun(q{Leonese})->is_singular  => q{is_singular: 'Leonese'};
ok noun(q{atman})->is_singular  => q{is_singular: 'atman'};
ok noun(q{lied})->is_singular  => q{is_singular: 'lied'};
ok noun(q{tsuba})->is_singular  => q{is_singular: 'tsuba'};
ok noun(q{papilla})->is_singular  => q{is_singular: 'papilla'};
ok noun(q{decennium})->is_singular  => q{is_singular: 'decennium'};
ok noun(q{dragoman})->is_singular  => q{is_singular: 'dragoman'};
ok noun(q{uredinium})->is_singular  => q{is_singular: 'uredinium'};
ok noun(q{pileus})->is_singular  => q{is_singular: 'pileus'};
ok noun(q{mycorrhiza})->is_singular  => q{is_singular: 'mycorrhiza'};
ok noun(q{lumbricus})->is_singular  => q{is_singular: 'lumbricus'};
ok noun(q{xanthoma})->is_singular  => q{is_singular: 'xanthoma'};
ok noun(q{casino})->is_singular  => q{is_singular: 'casino'};
ok noun(q{commando})->is_singular  => q{is_singular: 'commando'};
ok noun(q{supracleithrum})->is_singular  => q{is_singular: 'supracleithrum'};
ok noun(q{guano})->is_singular  => q{is_singular: 'guano'};
ok noun(q{shelf})->is_singular  => q{is_singular: 'shelf'};
ok noun(q{dipsas})->is_singular  => q{is_singular: 'dipsas'};
ok noun(q{radius})->is_singular  => q{is_singular: 'radius'};
ok noun(q{fiasco})->is_singular  => q{is_singular: 'fiasco'};
ok noun(q{base})->is_singular  => q{is_singular: 'base'};
ok noun(q{espresso})->is_singular  => q{is_singular: 'espresso'};
ok noun(q{nova})->is_singular  => q{is_singular: 'nova'};
ok noun(q{vaporetto})->is_singular  => q{is_singular: 'vaporetto'};
ok noun(q{terrarium})->is_singular  => q{is_singular: 'terrarium'};
ok noun(q{bulimus})->is_singular  => q{is_singular: 'bulimus'};
ok noun(q{hydria})->is_singular  => q{is_singular: 'hydria'};
ok noun(q{quarto})->is_singular  => q{is_singular: 'quarto'};
ok noun(q{carmen})->is_singular  => q{is_singular: 'carmen'};
ok noun(q{cistophorus})->is_singular  => q{is_singular: 'cistophorus'};
ok noun(q{oxyuris})->is_singular  => q{is_singular: 'oxyuris'};
ok noun(q{postnatus})->is_singular  => q{is_singular: 'postnatus'};
ok noun(q{glutaeus})->is_singular  => q{is_singular: 'glutaeus'};
ok noun(q{radix})->is_singular  => q{is_singular: 'radix'};
ok noun(q{xiphoplastron})->is_singular  => q{is_singular: 'xiphoplastron'};
ok noun(q{asyndeton})->is_singular  => q{is_singular: 'asyndeton'};
ok noun(q{coelia})->is_singular  => q{is_singular: 'coelia'};
ok noun(q{zeitgeber})->is_singular  => q{is_singular: 'zeitgeber'};
ok noun(q{siemens})->is_singular  => q{is_singular: 'siemens'};
ok noun(q{whomsoever})->is_singular  => q{is_singular: 'whomsoever'};
ok noun(q{staminidium})->is_singular  => q{is_singular: 'staminidium'};
ok noun(q{tagma})->is_singular  => q{is_singular: 'tagma'};
ok noun(q{Colombo})->is_singular  => q{is_singular: 'Colombo'};
ok noun(q{shomer})->is_singular  => q{is_singular: 'shomer'};
ok noun(q{nautilus})->is_singular  => q{is_singular: 'nautilus'};
ok noun(q{cappuccino})->is_singular  => q{is_singular: 'cappuccino'};
ok noun(q{thos})->is_singular  => q{is_singular: 'thos'};
ok noun(q{rione})->is_singular  => q{is_singular: 'rione'};
ok noun(q{ammo})->is_singular  => q{is_singular: 'ammo'};
ok noun(q{cementoma})->is_singular  => q{is_singular: 'cementoma'};
ok noun(q{genius})->is_singular  => q{is_singular: 'genius'};
ok noun(q{haustrum})->is_singular  => q{is_singular: 'haustrum'};
ok noun(q{Buginese})->is_singular  => q{is_singular: 'Buginese'};
ok noun(q{cavea})->is_singular  => q{is_singular: 'cavea'};
ok noun(q{zita})->is_singular  => q{is_singular: 'zita'};
ok noun(q{anti serum})->is_singular  => q{is_singular: 'anti serum'};
ok noun(q{peninsula})->is_singular  => q{is_singular: 'peninsula'};
ok noun(q{choana})->is_singular  => q{is_singular: 'choana'};
ok noun(q{scriptorium})->is_singular  => q{is_singular: 'scriptorium'};
ok noun(q{regidor})->is_singular  => q{is_singular: 'regidor'};
ok noun(q{pulmonarium})->is_singular  => q{is_singular: 'pulmonarium'};
ok noun(q{hoof})->is_singular  => q{is_singular: 'hoof'};
ok noun(q{whosesoever})->is_singular  => q{is_singular: 'whosesoever'};
ok noun(q{short})->is_singular  => q{is_singular: 'short'};
ok noun(q{solvus})->is_singular  => q{is_singular: 'solvus'};
ok noun(q{indigena})->is_singular  => q{is_singular: 'indigena'};
ok noun(q{testis})->is_singular  => q{is_singular: 'testis'};
ok noun(q{Niasese})->is_singular  => q{is_singular: 'Niasese'};
ok noun(q{trabecula})->is_singular  => q{is_singular: 'trabecula'};
ok noun(q{cornetto})->is_singular  => q{is_singular: 'cornetto'};
ok noun(q{brother-german})->is_singular  => q{is_singular: 'brother-german'};
ok noun(q{pedalo})->is_singular  => q{is_singular: 'pedalo'};
ok noun(q{cheval})->is_singular  => q{is_singular: 'cheval'};
ok noun(q{interradius})->is_singular  => q{is_singular: 'interradius'};
ok noun(q{trockenbeerenauslese})->is_singular  => q{is_singular: 'trockenbeerenauslese'};
ok noun(q{miliola})->is_singular  => q{is_singular: 'miliola'};
ok noun(q{Dongolese})->is_singular  => q{is_singular: 'Dongolese'};
ok noun(q{inuk})->is_singular  => q{is_singular: 'inuk'};
ok noun(q{scutulum})->is_singular  => q{is_singular: 'scutulum'};
ok noun(q{udarnik})->is_singular  => q{is_singular: 'udarnik'};
ok noun(q{parnas})->is_singular  => q{is_singular: 'parnas'};
ok noun(q{virga})->is_singular  => q{is_singular: 'virga'};
ok noun(q{intermezzo})->is_singular  => q{is_singular: 'intermezzo'};
ok noun(q{five star general})->is_singular  => q{is_singular: 'five star general'};
ok noun(q{carabiniere})->is_singular  => q{is_singular: 'carabiniere'};
ok noun(q{zloty})->is_singular  => q{is_singular: 'zloty'};
ok noun(q{varella})->is_singular  => q{is_singular: 'varella'};
ok noun(q{subbotnik})->is_singular  => q{is_singular: 'subbotnik'};
ok noun(q{oto})->is_singular  => q{is_singular: 'oto'};
ok noun(q{lemma})->is_singular  => q{is_singular: 'lemma'};
ok noun(q{romanze})->is_singular  => q{is_singular: 'romanze'};
ok noun(q{clavula})->is_singular  => q{is_singular: 'clavula'};
ok noun(q{osmeterium})->is_singular  => q{is_singular: 'osmeterium'};
ok noun(q{nephridium})->is_singular  => q{is_singular: 'nephridium'};
ok noun(q{scherzo})->is_singular  => q{is_singular: 'scherzo'};
ok noun(q{explanandum})->is_singular  => q{is_singular: 'explanandum'};
ok noun(q{wanderjahr})->is_singular  => q{is_singular: 'wanderjahr'};
ok noun(q{memento})->is_singular  => q{is_singular: 'memento'};
ok noun(q{psammoma})->is_singular  => q{is_singular: 'psammoma'};
ok noun(q{quartz})->is_singular  => q{is_singular: 'quartz'};
ok noun(q{zingano})->is_singular  => q{is_singular: 'zingano'};
ok noun(q{xoanon})->is_singular  => q{is_singular: 'xoanon'};
ok noun(q{canaliculus})->is_singular  => q{is_singular: 'canaliculus'};
ok noun(q{ax})->is_singular  => q{is_singular: 'ax'};
ok noun(q{mezuza})->is_singular  => q{is_singular: 'mezuza'};
ok noun(q{flatfoot})->is_singular  => q{is_singular: 'flatfoot'};
ok noun(q{punctum})->is_singular  => q{is_singular: 'punctum'};
ok noun(q{apparatus})->is_singular  => q{is_singular: 'apparatus'};
ok noun(q{alga})->is_singular  => q{is_singular: 'alga'};
ok noun(q{his})->is_singular  => q{is_singular: 'his'};
ok noun(q{star-fish})->is_singular  => q{is_singular: 'star-fish'};
ok noun(q{limulus})->is_singular  => q{is_singular: 'limulus'};
ok noun(q{antefix})->is_singular  => q{is_singular: 'antefix'};
ok noun(q{pasteurella})->is_singular  => q{is_singular: 'pasteurella'};
ok noun(q{nucleolus})->is_singular  => q{is_singular: 'nucleolus'};
ok noun(q{columbarium})->is_singular  => q{is_singular: 'columbarium'};
ok noun(q{crafts child})->is_singular  => q{is_singular: 'crafts child'};
ok noun(q{ballabile})->is_singular  => q{is_singular: 'ballabile'};
ok noun(q{testes})->is_singular  => q{is_singular: 'testes'};
ok noun(q{abacus})->is_singular  => q{is_singular: 'abacus'};
ok noun(q{pyrexia})->is_singular  => q{is_singular: 'pyrexia'};
ok noun(q{corpus})->is_singular  => q{is_singular: 'corpus'};
ok noun(q{euporiston})->is_singular  => q{is_singular: 'euporiston'};
ok noun(q{rideau})->is_singular  => q{is_singular: 'rideau'};
ok noun(q{apterium})->is_singular  => q{is_singular: 'apterium'};
ok noun(q{cul-de-four})->is_singular  => q{is_singular: 'cul-de-four'};
ok noun(q{relatum})->is_singular  => q{is_singular: 'relatum'};
ok noun(q{franc archer})->is_singular  => q{is_singular: 'franc archer'};
ok noun(q{nerita})->is_singular  => q{is_singular: 'nerita'};
ok noun(q{strategus})->is_singular  => q{is_singular: 'strategus'};
ok noun(q{man midwife})->is_singular  => q{is_singular: 'man midwife'};
ok noun(q{impetigo})->is_singular  => q{is_singular: 'impetigo'};
ok noun(q{grouse})->is_singular  => q{is_singular: 'grouse'};
ok noun(q{violetta})->is_singular  => q{is_singular: 'violetta'};
ok noun(q{monimolimnion})->is_singular  => q{is_singular: 'monimolimnion'};
ok noun(q{djinn})->is_singular  => q{is_singular: 'djinn'};
ok noun(q{siphunculus})->is_singular  => q{is_singular: 'siphunculus'};
ok noun(q{serpigo})->is_singular  => q{is_singular: 'serpigo'};
ok noun(q{retinula})->is_singular  => q{is_singular: 'retinula'};
ok noun(q{tubulus})->is_singular  => q{is_singular: 'tubulus'};
ok noun(q{mons})->is_singular  => q{is_singular: 'mons'};
ok noun(q{alumnus})->is_singular  => q{is_singular: 'alumnus'};
ok noun(q{falsetto})->is_singular  => q{is_singular: 'falsetto'};
ok noun(q{puttony})->is_singular  => q{is_singular: 'puttony'};
ok noun(q{arrha})->is_singular  => q{is_singular: 'arrha'};
ok noun(q{fenestra})->is_singular  => q{is_singular: 'fenestra'};
ok noun(q{staccato})->is_singular  => q{is_singular: 'staccato'};
ok noun(q{capataz})->is_singular  => q{is_singular: 'capataz'};
ok noun(q{digitalis})->is_singular  => q{is_singular: 'digitalis'};
ok noun(q{lens})->is_singular  => q{is_singular: 'lens'};
ok noun(q{obelus})->is_singular  => q{is_singular: 'obelus'};
ok noun(q{siliqua})->is_singular  => q{is_singular: 'siliqua'};
ok noun(q{contralto})->is_singular  => q{is_singular: 'contralto'};
ok noun(q{Wenchowese})->is_singular  => q{is_singular: 'Wenchowese'};
ok noun(q{Torinese})->is_singular  => q{is_singular: 'Torinese'};
ok noun(q{stillicidium})->is_singular  => q{is_singular: 'stillicidium'};
ok noun(q{man})->is_singular  => q{is_singular: 'man'};
ok noun(q{pelvis})->is_singular  => q{is_singular: 'pelvis'};
ok noun(q{Guaiabero})->is_singular  => q{is_singular: 'Guaiabero'};
ok noun(q{gubernaculum})->is_singular  => q{is_singular: 'gubernaculum'};
ok noun(q{ellipsis})->is_singular  => q{is_singular: 'ellipsis'};
ok noun(q{cassone})->is_singular  => q{is_singular: 'cassone'};
ok noun(q{tegmen})->is_singular  => q{is_singular: 'tegmen'};
ok noun(q{amoretto})->is_singular  => q{is_singular: 'amoretto'};
ok noun(q{voeu})->is_singular  => q{is_singular: 'voeu'};
ok noun(q{Chimango})->is_singular  => q{is_singular: 'Chimango'};
ok noun(q{phyogemmarium})->is_singular  => q{is_singular: 'phyogemmarium'};
ok noun(q{mausoleum})->is_singular  => q{is_singular: 'mausoleum'};
ok noun(q{thanatorium})->is_singular  => q{is_singular: 'thanatorium'};
ok noun(q{favissa})->is_singular  => q{is_singular: 'favissa'};
ok noun(q{soldo})->is_singular  => q{is_singular: 'soldo'};
ok noun(q{moroso})->is_singular  => q{is_singular: 'moroso'};
ok noun(q{co})->is_singular  => q{is_singular: 'co'};
ok noun(q{zoon})->is_singular  => q{is_singular: 'zoon'};
ok noun(q{pinon})->is_singular  => q{is_singular: 'pinon'};
ok noun(q{human})->is_singular  => q{is_singular: 'human'};
ok noun(q{Milano})->is_singular  => q{is_singular: 'Milano'};
ok noun(q{sgraffiato})->is_singular  => q{is_singular: 'sgraffiato'};
ok noun(q{cinclis})->is_singular  => q{is_singular: 'cinclis'};
ok noun(q{chapeau})->is_singular  => q{is_singular: 'chapeau'};
ok noun(q{murex})->is_singular  => q{is_singular: 'murex'};
ok noun(q{Indochinese})->is_singular  => q{is_singular: 'Indochinese'};
ok noun(q{phyle})->is_singular  => q{is_singular: 'phyle'};
ok noun(q{proscenium})->is_singular  => q{is_singular: 'proscenium'};
ok noun(q{bream})->is_singular  => q{is_singular: 'bream'};
ok noun(q{indumentum})->is_singular  => q{is_singular: 'indumentum'};
ok noun(q{datum})->is_singular  => q{is_singular: 'datum'};
ok noun(q{hippopotamus})->is_singular  => q{is_singular: 'hippopotamus'};
ok noun(q{paparrazo})->is_singular  => q{is_singular: 'paparrazo'};
ok noun(q{cactus})->is_singular  => q{is_singular: 'cactus'};
ok noun(q{geisteswissenschaft})->is_singular  => q{is_singular: 'geisteswissenschaft'};
ok noun(q{prothallus})->is_singular  => q{is_singular: 'prothallus'};
ok noun(q{allargando})->is_singular  => q{is_singular: 'allargando'};
ok noun(q{felo de se})->is_singular  => q{is_singular: 'felo de se'};
ok noun(q{morceau})->is_singular  => q{is_singular: 'morceau'};
ok noun(q{rhombohedron})->is_singular  => q{is_singular: 'rhombohedron'};
ok noun(q{mezzo rilievo})->is_singular  => q{is_singular: 'mezzo rilievo'};
ok noun(q{six star general})->is_singular  => q{is_singular: 'six star general'};
ok noun(q{primigravida})->is_singular  => q{is_singular: 'primigravida'};
ok noun(q{shifta})->is_singular  => q{is_singular: 'shifta'};
ok noun(q{Kongolese})->is_singular  => q{is_singular: 'Kongolese'};
ok noun(q{grissino})->is_singular  => q{is_singular: 'grissino'};
ok noun(q{Lapponese})->is_singular  => q{is_singular: 'Lapponese'};
ok noun(q{baal})->is_singular  => q{is_singular: 'baal'};
ok noun(q{offspring})->is_singular  => q{is_singular: 'offspring'};
ok noun(q{Sapporo})->is_singular  => q{is_singular: 'Sapporo'};
ok noun(q{pontifex})->is_singular  => q{is_singular: 'pontifex'};
ok noun(q{zophorus})->is_singular  => q{is_singular: 'zophorus'};
ok noun(q{abscissa})->is_singular  => q{is_singular: 'abscissa'};
ok noun(q{woman-servant})->is_singular  => q{is_singular: 'woman-servant'};
ok noun(q{primordium})->is_singular  => q{is_singular: 'primordium'};
ok noun(q{lumen})->is_singular  => q{is_singular: 'lumen'};
ok noun(q{Biro})->is_singular  => q{is_singular: 'Biro'};
ok noun(q{lieutenant general})->is_singular  => q{is_singular: 'lieutenant general'};
ok noun(q{grano})->is_singular  => q{is_singular: 'grano'};
ok noun(q{phallos})->is_singular  => q{is_singular: 'phallos'};
ok noun(q{insula})->is_singular  => q{is_singular: 'insula'};
ok noun(q{magneto})->is_singular  => q{is_singular: 'magneto'};
ok noun(q{differentia})->is_singular  => q{is_singular: 'differentia'};
ok noun(q{salvo})->is_singular  => q{is_singular: 'salvo'};
ok noun(q{lobulus})->is_singular  => q{is_singular: 'lobulus'};
ok noun(q{gonidium})->is_singular  => q{is_singular: 'gonidium'};
ok noun(q{sarcoma})->is_singular  => q{is_singular: 'sarcoma'};
ok noun(q{novus homo})->is_singular  => q{is_singular: 'novus homo'};
ok noun(q{metro})->is_singular  => q{is_singular: 'metro'};
ok noun(q{Sudanese})->is_singular  => q{is_singular: 'Sudanese'};
ok noun(q{dogma})->is_singular  => q{is_singular: 'dogma'};
ok noun(q{uncus})->is_singular  => q{is_singular: 'uncus'};
ok noun(q{axon})->is_singular  => q{is_singular: 'axon'};
ok noun(q{familia})->is_singular  => q{is_singular: 'familia'};
ok noun(q{ballerina})->is_singular  => q{is_singular: 'ballerina'};
ok noun(q{amphipneust})->is_singular  => q{is_singular: 'amphipneust'};
ok noun(q{minyan})->is_singular  => q{is_singular: 'minyan'};
ok noun(q{procoelia})->is_singular  => q{is_singular: 'procoelia'};
ok noun(q{progymnasma})->is_singular  => q{is_singular: 'progymnasma'};
ok noun(q{lacinia})->is_singular  => q{is_singular: 'lacinia'};
ok noun(q{sestiere})->is_singular  => q{is_singular: 'sestiere'};
ok noun(q{pipkrake})->is_singular  => q{is_singular: 'pipkrake'};
ok noun(q{gorgonia})->is_singular  => q{is_singular: 'gorgonia'};
ok noun(q{idolon})->is_singular  => q{is_singular: 'idolon'};
ok noun(q{tetrasporangium})->is_singular  => q{is_singular: 'tetrasporangium'};
ok noun(q{cargador})->is_singular  => q{is_singular: 'cargador'};
ok noun(q{phragma})->is_singular  => q{is_singular: 'phragma'};
ok noun(q{tiro})->is_singular  => q{is_singular: 'tiro'};
ok noun(q{scapus})->is_singular  => q{is_singular: 'scapus'};
ok noun(q{claustrum})->is_singular  => q{is_singular: 'claustrum'};
ok noun(q{municipium})->is_singular  => q{is_singular: 'municipium'};
ok noun(q{umbo})->is_singular  => q{is_singular: 'umbo'};
ok noun(q{line out})->is_singular  => q{is_singular: 'line out'};
ok noun(q{succubus})->is_singular  => q{is_singular: 'succubus'};
ok noun(q{rype})->is_singular  => q{is_singular: 'rype'};
ok noun(q{melanoma})->is_singular  => q{is_singular: 'melanoma'};
ok noun(q{auto})->is_singular  => q{is_singular: 'auto'};
ok noun(q{bechuana})->is_singular  => q{is_singular: 'bechuana'};
ok noun(q{Piedmontese})->is_singular  => q{is_singular: 'Piedmontese'};
ok noun(q{antenna})->is_singular  => q{is_singular: 'antenna'};
ok noun(q{cathisma})->is_singular  => q{is_singular: 'cathisma'};
ok noun(q{cimex})->is_singular  => q{is_singular: 'cimex'};
ok noun(q{vasculitis})->is_singular  => q{is_singular: 'vasculitis'};
ok noun(q{Virgo})->is_singular  => q{is_singular: 'Virgo'};
ok noun(q{rhopalium})->is_singular  => q{is_singular: 'rhopalium'};
ok noun(q{parnass})->is_singular  => q{is_singular: 'parnass'};
ok noun(q{lex humana})->is_singular  => q{is_singular: 'lex humana'};
ok noun(q{ligamentum})->is_singular  => q{is_singular: 'ligamentum'};
ok noun(q{beau geste})->is_singular  => q{is_singular: 'beau geste'};
ok noun(q{violoncello})->is_singular  => q{is_singular: 'violoncello'};
ok noun(q{Shawanese})->is_singular  => q{is_singular: 'Shawanese'};
ok noun(q{maar})->is_singular  => q{is_singular: 'maar'};
ok noun(q{blitz})->is_singular  => q{is_singular: 'blitz'};
ok noun(q{fibra})->is_singular  => q{is_singular: 'fibra'};
ok noun(q{monseigneur})->is_singular  => q{is_singular: 'monseigneur'};
ok noun(q{tintinnabulum})->is_singular  => q{is_singular: 'tintinnabulum'};
ok noun(q{spermogonium})->is_singular  => q{is_singular: 'spermogonium'};
ok noun(q{senex})->is_singular  => q{is_singular: 'senex'};
ok noun(q{Carlylese})->is_singular  => q{is_singular: 'Carlylese'};
ok noun(q{prospectus})->is_singular  => q{is_singular: 'prospectus'};
ok noun(q{mafioso})->is_singular  => q{is_singular: 'mafioso'};
ok noun(q{matinee musicale})->is_singular  => q{is_singular: 'matinee musicale'};
ok noun(q{tetanothrum})->is_singular  => q{is_singular: 'tetanothrum'};
ok noun(q{aphelion})->is_singular  => q{is_singular: 'aphelion'};
ok noun(q{terzetto})->is_singular  => q{is_singular: 'terzetto'};
ok noun(q{bravo})->is_singular  => q{is_singular: 'bravo'};
ok noun(q{sympodium})->is_singular  => q{is_singular: 'sympodium'};
ok noun(q{vis})->is_singular  => q{is_singular: 'vis'};
ok noun(q{axis})->is_singular  => q{is_singular: 'axis'};
ok noun(q{deer})->is_singular  => q{is_singular: 'deer'};
ok noun(q{Pistoiese})->is_singular  => q{is_singular: 'Pistoiese'};
ok noun(q{Guianese})->is_singular  => q{is_singular: 'Guianese'};
ok noun(q{Bhutanese})->is_singular  => q{is_singular: 'Bhutanese'};
ok noun(q{mukim})->is_singular  => q{is_singular: 'mukim'};
ok noun(q{megalosaurus})->is_singular  => q{is_singular: 'megalosaurus'};
ok noun(q{valuta})->is_singular  => q{is_singular: 'valuta'};
ok noun(q{brachiopod})->is_singular  => q{is_singular: 'brachiopod'};
ok noun(q{panto})->is_singular  => q{is_singular: 'panto'};
ok noun(q{alto})->is_singular  => q{is_singular: 'alto'};
ok noun(q{bifolium})->is_singular  => q{is_singular: 'bifolium'};
ok noun(q{kletterschuh})->is_singular  => q{is_singular: 'kletterschuh'};
ok noun(q{bureau})->is_singular  => q{is_singular: 'bureau'};
ok noun(q{alumna})->is_singular  => q{is_singular: 'alumna'};
ok noun(q{putto})->is_singular  => q{is_singular: 'putto'};
ok noun(q{euro})->is_singular  => q{is_singular: 'euro'};
ok noun(q{spiraculum})->is_singular  => q{is_singular: 'spiraculum'};
ok noun(q{ataman})->is_singular  => q{is_singular: 'ataman'};
ok noun(q{trapezium})->is_singular  => q{is_singular: 'trapezium'};
ok noun(q{rectus})->is_singular  => q{is_singular: 'rectus'};
ok noun(q{roe})->is_singular  => q{is_singular: 'roe'};
ok noun(q{olfactorium})->is_singular  => q{is_singular: 'olfactorium'};
ok noun(q{kar})->is_singular  => q{is_singular: 'kar'};
ok noun(q{drama})->is_singular  => q{is_singular: 'drama'};
ok noun(q{triumvir})->is_singular  => q{is_singular: 'triumvir'};
ok noun(q{hero})->is_singular  => q{is_singular: 'hero'};
ok noun(q{vortex})->is_singular  => q{is_singular: 'vortex'};
ok noun(q{Cairo})->is_singular  => q{is_singular: 'Cairo'};
ok noun(q{Mary})->is_singular  => q{is_singular: 'Mary'};
ok noun(q{perradius})->is_singular  => q{is_singular: 'perradius'};
ok noun(q{xiphopagus})->is_singular  => q{is_singular: 'xiphopagus'};
ok noun(q{crescendo})->is_singular  => q{is_singular: 'crescendo'};
ok noun(q{oculus})->is_singular  => q{is_singular: 'oculus'};
ok noun(q{Veronese})->is_singular  => q{is_singular: 'Veronese'};
ok noun(q{solo})->is_singular  => q{is_singular: 'solo'};
ok noun(q{ultimatum})->is_singular  => q{is_singular: 'ultimatum'};
ok noun(q{zeppole})->is_singular  => q{is_singular: 'zeppole'};
ok noun(q{lido})->is_singular  => q{is_singular: 'lido'};
ok noun(q{anthemion})->is_singular  => q{is_singular: 'anthemion'};
ok noun(q{prototypon})->is_singular  => q{is_singular: 'prototypon'};
ok noun(q{coe})->is_singular  => q{is_singular: 'coe'};
ok noun(q{jambeau})->is_singular  => q{is_singular: 'jambeau'};
ok noun(q{apothecium})->is_singular  => q{is_singular: 'apothecium'};
ok noun(q{oregano})->is_singular  => q{is_singular: 'oregano'};
ok noun(q{fulcrum})->is_singular  => q{is_singular: 'fulcrum'};
ok noun(q{struma})->is_singular  => q{is_singular: 'struma'};
ok noun(q{polo})->is_singular  => q{is_singular: 'polo'};
ok noun(q{Sarawakese})->is_singular  => q{is_singular: 'Sarawakese'};
ok noun(q{stryddag})->is_singular  => q{is_singular: 'stryddag'};
ok noun(q{plasmolyticum})->is_singular  => q{is_singular: 'plasmolyticum'};
ok noun(q{bingo})->is_singular  => q{is_singular: 'bingo'};
ok noun(q{topos})->is_singular  => q{is_singular: 'topos'};
ok noun(q{duumvir})->is_singular  => q{is_singular: 'duumvir'};
ok noun(q{castrato})->is_singular  => q{is_singular: 'castrato'};
ok noun(q{zygantrum})->is_singular  => q{is_singular: 'zygantrum'};
ok noun(q{Romany})->is_singular  => q{is_singular: 'Romany'};
ok noun(q{spasmus})->is_singular  => q{is_singular: 'spasmus'};
ok noun(q{osmaterium})->is_singular  => q{is_singular: 'osmaterium'};
ok noun(q{judas})->is_singular  => q{is_singular: 'judas'};
ok noun(q{intichiuma})->is_singular  => q{is_singular: 'intichiuma'};
ok noun(q{Malabo})->is_singular  => q{is_singular: 'Malabo'};
ok noun(q{aegis})->is_singular  => q{is_singular: 'aegis'};
ok noun(q{diporpa})->is_singular  => q{is_singular: 'diporpa'};
ok noun(q{urodeum})->is_singular  => q{is_singular: 'urodeum'};
ok noun(q{ascidium})->is_singular  => q{is_singular: 'ascidium'};
ok noun(q{rejoneador})->is_singular  => q{is_singular: 'rejoneador'};
ok noun(q{basso})->is_singular  => q{is_singular: 'basso'};
ok noun(q{spectrum})->is_singular  => q{is_singular: 'spectrum'};
ok noun(q{spirillum})->is_singular  => q{is_singular: 'spirillum'};
ok noun(q{coitus})->is_singular  => q{is_singular: 'coitus'};
ok noun(q{frottola})->is_singular  => q{is_singular: 'frottola'};
ok noun(q{subsellium})->is_singular  => q{is_singular: 'subsellium'};
ok noun(q{ancona})->is_singular  => q{is_singular: 'ancona'};
ok noun(q{whomever})->is_singular  => q{is_singular: 'whomever'};
ok noun(q{directrix})->is_singular  => q{is_singular: 'directrix'};
ok noun(q{haggis})->is_singular  => q{is_singular: 'haggis'};
ok noun(q{tepidarium})->is_singular  => q{is_singular: 'tepidarium'};
ok noun(q{lis})->is_singular  => q{is_singular: 'lis'};
ok noun(q{palpebra})->is_singular  => q{is_singular: 'palpebra'};
ok noun(q{trullo})->is_singular  => q{is_singular: 'trullo'};
ok noun(q{pina colada})->is_singular  => q{is_singular: 'pina colada'};
ok noun(q{sorus})->is_singular  => q{is_singular: 'sorus'};
ok noun(q{equisetum})->is_singular  => q{is_singular: 'equisetum'};
ok noun(q{opusculum})->is_singular  => q{is_singular: 'opusculum'};
ok noun(q{mitochondrion})->is_singular  => q{is_singular: 'mitochondrion'};
ok noun(q{innings})->is_singular  => q{is_singular: 'innings'};
ok noun(q{purum})->is_singular  => q{is_singular: 'purum'};
ok noun(q{thesaurus})->is_singular  => q{is_singular: 'thesaurus'};
ok noun(q{snekkja})->is_singular  => q{is_singular: 'snekkja'};
ok noun(q{simplex})->is_singular  => q{is_singular: 'simplex'};
ok noun(q{gumbo})->is_singular  => q{is_singular: 'gumbo'};
ok noun(q{woman-child})->is_singular  => q{is_singular: 'woman-child'};
ok noun(q{hydra})->is_singular  => q{is_singular: 'hydra'};
ok noun(q{Orlando})->is_singular  => q{is_singular: 'Orlando'};
ok noun(q{bylina})->is_singular  => q{is_singular: 'bylina'};
ok noun(q{stipula})->is_singular  => q{is_singular: 'stipula'};
ok noun(q{mumps})->is_singular  => q{is_singular: 'mumps'};
ok noun(q{symposium})->is_singular  => q{is_singular: 'symposium'};
ok noun(q{tornus})->is_singular  => q{is_singular: 'tornus'};
ok noun(q{entente cordiale})->is_singular  => q{is_singular: 'entente cordiale'};
ok noun(q{lipoma})->is_singular  => q{is_singular: 'lipoma'};
ok noun(q{ephelis})->is_singular  => q{is_singular: 'ephelis'};
ok noun(q{rara avis})->is_singular  => q{is_singular: 'rara avis'};
ok noun(q{zoophorus})->is_singular  => q{is_singular: 'zoophorus'};
ok noun(q{unio})->is_singular  => q{is_singular: 'unio'};
ok noun(q{scarabaeus})->is_singular  => q{is_singular: 'scarabaeus'};
ok noun(q{German})->is_singular  => q{is_singular: 'German'};
ok noun(q{lapith})->is_singular  => q{is_singular: 'lapith'};
ok noun(q{Roman})->is_singular  => q{is_singular: 'Roman'};
ok noun(q{Oklahoman})->is_singular  => q{is_singular: 'Oklahoman'};
ok noun(q{Liman})->is_singular  => q{is_singular: 'Liman'};
ok noun(q{interleaf})->is_singular  => q{is_singular: 'interleaf'};
ok noun(q{Pluto})->is_singular  => q{is_singular: 'Pluto'};
ok noun(q{clepsydra})->is_singular  => q{is_singular: 'clepsydra'};
ok noun(q{addendum})->is_singular  => q{is_singular: 'addendum'};
ok noun(q{set-out})->is_singular  => q{is_singular: 'set-out'};
ok noun(q{autochthon})->is_singular  => q{is_singular: 'autochthon'};
ok noun(q{quid})->is_singular  => q{is_singular: 'quid'};
ok noun(q{mantis})->is_singular  => q{is_singular: 'mantis'};
ok noun(q{trout})->is_singular  => q{is_singular: 'trout'};
ok noun(q{hypnum})->is_singular  => q{is_singular: 'hypnum'};
ok noun(q{enconium})->is_singular  => q{is_singular: 'enconium'};
ok noun(q{malum in se})->is_singular  => q{is_singular: 'malum in se'};
ok noun(q{carte-de-visite})->is_singular  => q{is_singular: 'carte-de-visite'};
ok noun(q{palus})->is_singular  => q{is_singular: 'palus'};
ok noun(q{eros})->is_singular  => q{is_singular: 'eros'};
ok noun(q{improperium})->is_singular  => q{is_singular: 'improperium'};
ok noun(q{dichasium})->is_singular  => q{is_singular: 'dichasium'};
ok noun(q{Bostonese})->is_singular  => q{is_singular: 'Bostonese'};
ok noun(q{grotto})->is_singular  => q{is_singular: 'grotto'};
ok noun(q{tablinum})->is_singular  => q{is_singular: 'tablinum'};
ok noun(q{mortarium})->is_singular  => q{is_singular: 'mortarium'};
ok noun(q{pecten})->is_singular  => q{is_singular: 'pecten'};
ok noun(q{credo})->is_singular  => q{is_singular: 'credo'};
ok noun(q{zooecium})->is_singular  => q{is_singular: 'zooecium'};
ok noun(q{neurula})->is_singular  => q{is_singular: 'neurula'};
ok noun(q{denotatum})->is_singular  => q{is_singular: 'denotatum'};
ok noun(q{sforzato})->is_singular  => q{is_singular: 'sforzato'};
ok noun(q{Auslese})->is_singular  => q{is_singular: 'Auslese'};
ok noun(q{swine})->is_singular  => q{is_singular: 'swine'};
ok noun(q{frustulum})->is_singular  => q{is_singular: 'frustulum'};
ok noun(q{situla})->is_singular  => q{is_singular: 'situla'};
ok noun(q{cony})->is_singular  => q{is_singular: 'cony'};
ok noun(q{lamella})->is_singular  => q{is_singular: 'lamella'};
ok noun(q{porion})->is_singular  => q{is_singular: 'porion'};
ok noun(q{sagum})->is_singular  => q{is_singular: 'sagum'};
ok noun(q{maremma})->is_singular  => q{is_singular: 'maremma'};
ok noun(q{ustilago})->is_singular  => q{is_singular: 'ustilago'};
ok noun(q{aurora})->is_singular  => q{is_singular: 'aurora'};
ok noun(q{propositus})->is_singular  => q{is_singular: 'propositus'};
ok noun(q{Javanese})->is_singular  => q{is_singular: 'Javanese'};
ok noun(q{squama})->is_singular  => q{is_singular: 'squama'};
ok noun(q{Tornese})->is_singular  => q{is_singular: 'Tornese'};
ok noun(q{karakia})->is_singular  => q{is_singular: 'karakia'};
ok noun(q{superstratum})->is_singular  => q{is_singular: 'superstratum'};
ok noun(q{torso})->is_singular  => q{is_singular: 'torso'};
ok noun(q{sparus})->is_singular  => q{is_singular: 'sparus'};
ok noun(q{die})->is_singular  => q{is_singular: 'die'};
ok noun(q{candelabrum})->is_singular  => q{is_singular: 'candelabrum'};
ok noun(q{burro})->is_singular  => q{is_singular: 'burro'};
ok noun(q{pyrites})->is_singular  => q{is_singular: 'pyrites'};
ok noun(q{asterias})->is_singular  => q{is_singular: 'asterias'};
ok noun(q{phallus})->is_singular  => q{is_singular: 'phallus'};
ok noun(q{conversazione})->is_singular  => q{is_singular: 'conversazione'};
ok noun(q{phototaxis})->is_singular  => q{is_singular: 'phototaxis'};
ok noun(q{synthronus})->is_singular  => q{is_singular: 'synthronus'};
ok noun(q{clausula})->is_singular  => q{is_singular: 'clausula'};
ok noun(q{Taiko})->is_singular  => q{is_singular: 'Taiko'};
ok noun(q{senarius})->is_singular  => q{is_singular: 'senarius'};
ok noun(q{mythos})->is_singular  => q{is_singular: 'mythos'};
ok noun(q{rhododendron})->is_singular  => q{is_singular: 'rhododendron'};
ok noun(q{carte de visite})->is_singular  => q{is_singular: 'carte de visite'};
ok noun(q{onager})->is_singular  => q{is_singular: 'onager'};
ok noun(q{nasutus})->is_singular  => q{is_singular: 'nasutus'};
ok noun(q{placebo})->is_singular  => q{is_singular: 'placebo'};
ok noun(q{Yunnanese})->is_singular  => q{is_singular: 'Yunnanese'};
ok noun(q{tentaculum})->is_singular  => q{is_singular: 'tentaculum'};
ok noun(q{medium})->is_singular  => q{is_singular: 'medium'};
ok noun(q{ixodid})->is_singular  => q{is_singular: 'ixodid'};
ok noun(q{consortium})->is_singular  => q{is_singular: 'consortium'};
ok noun(q{medulloblastoma})->is_singular  => q{is_singular: 'medulloblastoma'};
ok noun(q{konditorei})->is_singular  => q{is_singular: 'konditorei'};
ok noun(q{corps general})->is_singular  => q{is_singular: 'corps general'};
ok noun(q{topaz})->is_singular  => q{is_singular: 'topaz'};
ok noun(q{flag staff})->is_singular  => q{is_singular: 'flag staff'};
ok noun(q{debris})->is_singular  => q{is_singular: 'debris'};
ok noun(q{lyssa})->is_singular  => q{is_singular: 'lyssa'};
ok noun(q{leishmania})->is_singular  => q{is_singular: 'leishmania'};
ok noun(q{mediatrix})->is_singular  => q{is_singular: 'mediatrix'};
ok noun(q{starosta})->is_singular  => q{is_singular: 'starosta'};
ok noun(q{Sonaman})->is_singular  => q{is_singular: 'Sonaman'};
ok noun(q{acroama})->is_singular  => q{is_singular: 'acroama'};
ok noun(q{bratwurst})->is_singular  => q{is_singular: 'bratwurst'};
ok noun(q{uomo})->is_singular  => q{is_singular: 'uomo'};
ok noun(q{shear})->is_singular  => q{is_singular: 'shear'};
ok noun(q{serir})->is_singular  => q{is_singular: 'serir'};
ok noun(q{plurale tantum})->is_singular  => q{is_singular: 'plurale tantum'};
ok noun(q{ricordo})->is_singular  => q{is_singular: 'ricordo'};
ok noun(q{funambulus})->is_singular  => q{is_singular: 'funambulus'};
ok noun(q{helion})->is_singular  => q{is_singular: 'helion'};
ok noun(q{coup d'etat})->is_singular  => q{is_singular: 'coup d'etat'};
ok noun(q{stichos})->is_singular  => q{is_singular: 'stichos'};
ok noun(q{cul de sac})->is_singular  => q{is_singular: 'cul de sac'};
ok noun(q{trauma})->is_singular  => q{is_singular: 'trauma'};
ok noun(q{alto-relievo})->is_singular  => q{is_singular: 'alto-relievo'};
ok noun(q{scutum})->is_singular  => q{is_singular: 'scutum'};
ok noun(q{saxicava})->is_singular  => q{is_singular: 'saxicava'};
ok noun(q{syntagma})->is_singular  => q{is_singular: 'syntagma'};
ok noun(q{medico})->is_singular  => q{is_singular: 'medico'};
ok noun(q{clipper})->is_singular  => q{is_singular: 'clipper'};
ok noun(q{occiput})->is_singular  => q{is_singular: 'occiput'};
ok noun(q{eucalyptus})->is_singular  => q{is_singular: 'eucalyptus'};
ok noun(q{tractrix})->is_singular  => q{is_singular: 'tractrix'};
ok noun(q{menu})->is_singular  => q{is_singular: 'menu'};
ok noun(q{Selman})->is_singular  => q{is_singular: 'Selman'};
ok noun(q{jo})->is_singular  => q{is_singular: 'jo'};
ok noun(q{tympanum})->is_singular  => q{is_singular: 'tympanum'};
ok noun(q{remous})->is_singular  => q{is_singular: 'remous'};
ok noun(q{Tocharese})->is_singular  => q{is_singular: 'Tocharese'};
ok noun(q{pangasinan})->is_singular  => q{is_singular: 'pangasinan'};
ok noun(q{switchfoot})->is_singular  => q{is_singular: 'switchfoot'};
ok noun(q{epimeron})->is_singular  => q{is_singular: 'epimeron'};
ok noun(q{vena})->is_singular  => q{is_singular: 'vena'};
ok noun(q{pengo})->is_singular  => q{is_singular: 'pengo'};
ok noun(q{ocellus})->is_singular  => q{is_singular: 'ocellus'};
ok noun(q{guttus})->is_singular  => q{is_singular: 'guttus'};
ok noun(q{man servant})->is_singular  => q{is_singular: 'man servant'};
ok noun(q{Yengeese})->is_singular  => q{is_singular: 'Yengeese'};
ok noun(q{volcano})->is_singular  => q{is_singular: 'volcano'};
ok noun(q{corrigendum})->is_singular  => q{is_singular: 'corrigendum'};
ok noun(q{weirdo})->is_singular  => q{is_singular: 'weirdo'};
ok noun(q{pollex})->is_singular  => q{is_singular: 'pollex'};
ok noun(q{hubris})->is_singular  => q{is_singular: 'hubris'};
ok noun(q{varia lectio})->is_singular  => q{is_singular: 'varia lectio'};
ok noun(q{hyperbola})->is_singular  => q{is_singular: 'hyperbola'};
ok noun(q{5-star general})->is_singular  => q{is_singular: '5-star general'};
ok noun(q{storey})->is_singular  => q{is_singular: 'storey'};
ok noun(q{vomitorium})->is_singular  => q{is_singular: 'vomitorium'};
ok noun(q{pistillidium})->is_singular  => q{is_singular: 'pistillidium'};
ok noun(q{moratorium})->is_singular  => q{is_singular: 'moratorium'};
ok noun(q{Romanese})->is_singular  => q{is_singular: 'Romanese'};
ok noun(q{seaquarium})->is_singular  => q{is_singular: 'seaquarium'};
ok noun(q{hiatus})->is_singular  => q{is_singular: 'hiatus'};
ok noun(q{turbot})->is_singular  => q{is_singular: 'turbot'};
ok noun(q{spermarium})->is_singular  => q{is_singular: 'spermarium'};
ok noun(q{ovum})->is_singular  => q{is_singular: 'ovum'};
ok noun(q{Celanese})->is_singular  => q{is_singular: 'Celanese'};
ok noun(q{synaxarion})->is_singular  => q{is_singular: 'synaxarion'};
ok noun(q{geisha})->is_singular  => q{is_singular: 'geisha'};
ok noun(q{chaos})->is_singular  => q{is_singular: 'chaos'};
ok noun(q{fucus})->is_singular  => q{is_singular: 'fucus'};
ok noun(q{hallux})->is_singular  => q{is_singular: 'hallux'};
ok noun(q{listerella})->is_singular  => q{is_singular: 'listerella'};
ok noun(q{eland})->is_singular  => q{is_singular: 'eland'};
ok noun(q{pholas})->is_singular  => q{is_singular: 'pholas'};
ok noun(q{omentum})->is_singular  => q{is_singular: 'omentum'};
ok noun(q{semuncia})->is_singular  => q{is_singular: 'semuncia'};
ok noun(q{teal})->is_singular  => q{is_singular: 'teal'};
ok noun(q{me})->is_singular  => q{is_singular: 'me'};
ok noun(q{five-star general})->is_singular  => q{is_singular: 'five-star general'};
ok noun(q{bema})->is_singular  => q{is_singular: 'bema'};
ok noun(q{Kanarese})->is_singular  => q{is_singular: 'Kanarese'};
ok noun(q{canvas})->is_singular  => q{is_singular: 'canvas'};
ok noun(q{tete-a-tete})->is_singular  => q{is_singular: 'tete-a-tete'};
ok noun(q{fundamentum divisionis})->is_singular  => q{is_singular: 'fundamentum divisionis'};
ok noun(q{antrum})->is_singular  => q{is_singular: 'antrum'};
ok noun(q{anti-serum})->is_singular  => q{is_singular: 'anti-serum'};
ok noun(q{chervonetz})->is_singular  => q{is_singular: 'chervonetz'};
ok noun(q{Heavenese})->is_singular  => q{is_singular: 'Heavenese'};
ok noun(q{three star general})->is_singular  => q{is_singular: 'three star general'};
ok noun(q{pox})->is_singular  => q{is_singular: 'pox'};
ok noun(q{phlegmasia})->is_singular  => q{is_singular: 'phlegmasia'};
ok noun(q{obolus})->is_singular  => q{is_singular: 'obolus'};
ok noun(q{corpus vile})->is_singular  => q{is_singular: 'corpus vile'};
ok noun(q{villus})->is_singular  => q{is_singular: 'villus'};
ok noun(q{zero})->is_singular  => q{is_singular: 'zero'};
ok noun(q{sceat})->is_singular  => q{is_singular: 'sceat'};
ok noun(q{anathema})->is_singular  => q{is_singular: 'anathema'};
ok noun(q{numen})->is_singular  => q{is_singular: 'numen'};
ok noun(q{adytum})->is_singular  => q{is_singular: 'adytum'};
ok noun(q{noxa})->is_singular  => q{is_singular: 'noxa'};
ok noun(q{Sinhalese})->is_singular  => q{is_singular: 'Sinhalese'};
ok noun(q{hamadryad})->is_singular  => q{is_singular: 'hamadryad'};
ok noun(q{buzz})->is_singular  => q{is_singular: 'buzz'};
ok noun(q{zuz})->is_singular  => q{is_singular: 'zuz'};
ok noun(q{stoa})->is_singular  => q{is_singular: 'stoa'};
ok noun(q{tete a tete})->is_singular  => q{is_singular: 'tete a tete'};
ok noun(q{punto blanco})->is_singular  => q{is_singular: 'punto blanco'};
ok noun(q{diploma})->is_singular  => q{is_singular: 'diploma'};
ok noun(q{agendum})->is_singular  => q{is_singular: 'agendum'};
ok noun(q{desideratum})->is_singular  => q{is_singular: 'desideratum'};
ok noun(q{aide de camp})->is_singular  => q{is_singular: 'aide de camp'};
ok noun(q{ceriman})->is_singular  => q{is_singular: 'ceriman'};
ok noun(q{breech})->is_singular  => q{is_singular: 'breech'};
ok noun(q{Portuguese})->is_singular  => q{is_singular: 'Portuguese'};
ok noun(q{mango})->is_singular  => q{is_singular: 'mango'};
ok noun(q{telium})->is_singular  => q{is_singular: 'telium'};
ok noun(q{goy})->is_singular  => q{is_singular: 'goy'};
ok noun(q{he})->is_singular  => q{is_singular: 'he'};
ok noun(q{Galla})->is_singular  => q{is_singular: 'Galla'};
ok noun(q{flatus})->is_singular  => q{is_singular: 'flatus'};
ok noun(q{-ox})->is_singular  => q{is_singular: '-ox'};
ok noun(q{starover})->is_singular  => q{is_singular: 'starover'};
ok noun(q{tabella})->is_singular  => q{is_singular: 'tabella'};
ok noun(q{terramara})->is_singular  => q{is_singular: 'terramara'};
ok noun(q{representamen})->is_singular  => q{is_singular: 'representamen'};
ok noun(q{beau})->is_singular  => q{is_singular: 'beau'};
ok noun(q{Congolese})->is_singular  => q{is_singular: 'Congolese'};
ok noun(q{lithophyton})->is_singular  => q{is_singular: 'lithophyton'};
ok noun(q{menage a quatre})->is_singular  => q{is_singular: 'menage a quatre'};
ok noun(q{bona fides})->is_singular  => q{is_singular: 'bona fides'};
ok noun(q{divisional general})->is_singular  => q{is_singular: 'divisional general'};
ok noun(q{interrex})->is_singular  => q{is_singular: 'interrex'};
ok noun(q{Nepalese})->is_singular  => q{is_singular: 'Nepalese'};
ok noun(q{Madurese})->is_singular  => q{is_singular: 'Madurese'};
ok noun(q{solfeggio})->is_singular  => q{is_singular: 'solfeggio'};
ok noun(q{caryatid})->is_singular  => q{is_singular: 'caryatid'};
ok noun(q{wildebeest})->is_singular  => q{is_singular: 'wildebeest'};
ok noun(q{tergum})->is_singular  => q{is_singular: 'tergum'};
ok noun(q{trochus})->is_singular  => q{is_singular: 'trochus'};
ok noun(q{bass})->is_singular  => q{is_singular: 'bass'};
ok noun(q{femur})->is_singular  => q{is_singular: 'femur'};
ok noun(q{supercilium})->is_singular  => q{is_singular: 'supercilium'};
ok noun(q{contrafactum})->is_singular  => q{is_singular: 'contrafactum'};
ok noun(q{millennium})->is_singular  => q{is_singular: 'millennium'};
ok noun(q{pulveratrix})->is_singular  => q{is_singular: 'pulveratrix'};
ok noun(q{zoea})->is_singular  => q{is_singular: 'zoea'};
ok noun(q{haemangioma})->is_singular  => q{is_singular: 'haemangioma'};
ok noun(q{yours})->is_singular  => q{is_singular: 'yours'};
ok noun(q{perikaryon})->is_singular  => q{is_singular: 'perikaryon'};
ok noun(q{separatrix})->is_singular  => q{is_singular: 'separatrix'};
ok noun(q{captain general})->is_singular  => q{is_singular: 'captain general'};
ok noun(q{sabertooth})->is_singular  => q{is_singular: 'sabertooth'};
ok noun(q{pecia})->is_singular  => q{is_singular: 'pecia'};
ok noun(q{cysticercus})->is_singular  => q{is_singular: 'cysticercus'};
ok noun(q{bajocco})->is_singular  => q{is_singular: 'bajocco'};
ok noun(q{sternebra})->is_singular  => q{is_singular: 'sternebra'};
ok noun(q{theca})->is_singular  => q{is_singular: 'theca'};
ok noun(q{chlamydia})->is_singular  => q{is_singular: 'chlamydia'};
ok noun(q{cheval de bataille})->is_singular  => q{is_singular: 'cheval de bataille'};
ok noun(q{alula})->is_singular  => q{is_singular: 'alula'};
ok noun(q{set to})->is_singular  => q{is_singular: 'set to'};
ok noun(q{four star general})->is_singular  => q{is_singular: 'four star general'};
ok noun(q{calypso})->is_singular  => q{is_singular: 'calypso'};
ok noun(q{caiman})->is_singular  => q{is_singular: 'caiman'};
ok noun(q{dilettante})->is_singular  => q{is_singular: 'dilettante'};
ok noun(q{tongs})->is_singular  => q{is_singular: 'tongs'};
ok noun(q{waltz})->is_singular  => q{is_singular: 'waltz'};
ok noun(q{troparion})->is_singular  => q{is_singular: 'troparion'};
ok noun(q{6-star general})->is_singular  => q{is_singular: '6-star general'};
ok noun(q{scalenus})->is_singular  => q{is_singular: 'scalenus'};
ok noun(q{gemma})->is_singular  => q{is_singular: 'gemma'};
ok noun(q{Balinese})->is_singular  => q{is_singular: 'Balinese'};
ok noun(q{ski})->is_singular  => q{is_singular: 'ski'};
ok noun(q{actinia})->is_singular  => q{is_singular: 'actinia'};
ok noun(q{bel esprit})->is_singular  => q{is_singular: 'bel esprit'};
ok noun(q{child})->is_singular  => q{is_singular: 'child'};
ok noun(q{delirium})->is_singular  => q{is_singular: 'delirium'};
ok noun(q{cortex})->is_singular  => q{is_singular: 'cortex'};
ok noun(q{ibis})->is_singular  => q{is_singular: 'ibis'};
ok noun(q{theirs})->is_singular  => q{is_singular: 'theirs'};
ok noun(q{emporium})->is_singular  => q{is_singular: 'emporium'};
ok noun(q{Swahilese})->is_singular  => q{is_singular: 'Swahilese'};
ok noun(q{torero})->is_singular  => q{is_singular: 'torero'};
ok noun(q{blue})->is_singular  => q{is_singular: 'blue'};
ok noun(q{surculus})->is_singular  => q{is_singular: 'surculus'};
ok noun(q{epyllion})->is_singular  => q{is_singular: 'epyllion'};
ok noun(q{lingula})->is_singular  => q{is_singular: 'lingula'};
ok noun(q{serra})->is_singular  => q{is_singular: 'serra'};
ok noun(q{herr})->is_singular  => q{is_singular: 'herr'};
ok noun(q{modulus})->is_singular  => q{is_singular: 'modulus'};
ok noun(q{salita})->is_singular  => q{is_singular: 'salita'};
ok noun(q{polis})->is_singular  => q{is_singular: 'polis'};
ok noun(q{prosodiencephalon})->is_singular  => q{is_singular: 'prosodiencephalon'};
ok noun(q{meris})->is_singular  => q{is_singular: 'meris'};
ok noun(q{meshummad})->is_singular  => q{is_singular: 'meshummad'};
ok noun(q{nagaika})->is_singular  => q{is_singular: 'nagaika'};
ok noun(q{exemplum})->is_singular  => q{is_singular: 'exemplum'};
ok noun(q{penicillus})->is_singular  => q{is_singular: 'penicillus'};
ok noun(q{whatsoever})->is_singular  => q{is_singular: 'whatsoever'};
ok noun(q{summum genus})->is_singular  => q{is_singular: 'summum genus'};
ok noun(q{flora})->is_singular  => q{is_singular: 'flora'};
ok noun(q{terminus})->is_singular  => q{is_singular: 'terminus'};
ok noun(q{wandervogel})->is_singular  => q{is_singular: 'wandervogel'};
ok noun(q{otomi})->is_singular  => q{is_singular: 'otomi'};
ok noun(q{joe})->is_singular  => q{is_singular: 'joe'};
ok noun(q{tessera})->is_singular  => q{is_singular: 'tessera'};
ok noun(q{ephemeris})->is_singular  => q{is_singular: 'ephemeris'};
ok noun(q{desman})->is_singular  => q{is_singular: 'desman'};
ok noun(q{kuvasz})->is_singular  => q{is_singular: 'kuvasz'};
ok noun(q{pant})->is_singular  => q{is_singular: 'pant'};
ok noun(q{ergastulum})->is_singular  => q{is_singular: 'ergastulum'};
ok noun(q{Bahaman})->is_singular  => q{is_singular: 'Bahaman'};
ok noun(q{kovsh})->is_singular  => q{is_singular: 'kovsh'};
ok noun(q{leptomonas})->is_singular  => q{is_singular: 'leptomonas'};
ok noun(q{portmanteau})->is_singular  => q{is_singular: 'portmanteau'};
ok noun(q{port a beul})->is_singular  => q{is_singular: 'port a beul'};
ok noun(q{inhalatorium})->is_singular  => q{is_singular: 'inhalatorium'};
ok noun(q{plasmodium})->is_singular  => q{is_singular: 'plasmodium'};
ok noun(q{corgi})->is_singular  => q{is_singular: 'corgi'};
ok noun(q{bronchitis})->is_singular  => q{is_singular: 'bronchitis'};
ok noun(q{parapleura})->is_singular  => q{is_singular: 'parapleura'};
ok noun(q{aviso})->is_singular  => q{is_singular: 'aviso'};
ok noun(q{viscus})->is_singular  => q{is_singular: 'viscus'};
ok noun(q{hemi-elytrum})->is_singular  => q{is_singular: 'hemi-elytrum'};
ok noun(q{2-star general})->is_singular  => q{is_singular: '2-star general'};
ok noun(q{it})->is_singular  => q{is_singular: 'it'};
ok noun(q{proavis})->is_singular  => q{is_singular: 'proavis'};
ok noun(q{stirps})->is_singular  => q{is_singular: 'stirps'};
ok noun(q{whosoever})->is_singular  => q{is_singular: 'whosoever'};
ok noun(q{portrait parle})->is_singular  => q{is_singular: 'portrait parle'};
ok noun(q{scissors})->is_singular  => q{is_singular: 'scissors'};
ok noun(q{siglos})->is_singular  => q{is_singular: 'siglos'};
ok noun(q{musa})->is_singular  => q{is_singular: 'musa'};
ok noun(q{vacuum})->is_singular  => q{is_singular: 'vacuum'};
ok noun(q{plenarium})->is_singular  => q{is_singular: 'plenarium'};
ok noun(q{sistrum})->is_singular  => q{is_singular: 'sistrum'};
ok noun(q{judicatum})->is_singular  => q{is_singular: 'judicatum'};
ok noun(q{rad})->is_singular  => q{is_singular: 'rad'};
ok noun(q{himself})->is_singular  => q{is_singular: 'himself'};
ok noun(q{sputum})->is_singular  => q{is_singular: 'sputum'};
ok noun(q{tholus})->is_singular  => q{is_singular: 'tholus'};
ok noun(q{micronucleus})->is_singular  => q{is_singular: 'micronucleus'};
ok noun(q{shawabti})->is_singular  => q{is_singular: 'shawabti'};
ok noun(q{sassafras})->is_singular  => q{is_singular: 'sassafras'};
ok noun(q{Whitmanese})->is_singular  => q{is_singular: 'Whitmanese'};
ok noun(q{propylaeum})->is_singular  => q{is_singular: 'propylaeum'};
ok noun(q{umbra})->is_singular  => q{is_singular: 'umbra'};
ok noun(q{stylo})->is_singular  => q{is_singular: 'stylo'};
ok noun(q{port-a-beul})->is_singular  => q{is_singular: 'port-a-beul'};
ok noun(q{they})->is_singular  => q{is_singular: 'they'};
ok noun(q{paha})->is_singular  => q{is_singular: 'paha'};
ok noun(q{perceptum})->is_singular  => q{is_singular: 'perceptum'};
ok noun(q{testudo})->is_singular  => q{is_singular: 'testudo'};
ok noun(q{phyma})->is_singular  => q{is_singular: 'phyma'};
ok noun(q{Tokyo})->is_singular  => q{is_singular: 'Tokyo'};
ok noun(q{proceedings})->is_singular  => q{is_singular: 'proceedings'};
ok noun(q{legumen})->is_singular  => q{is_singular: 'legumen'};
ok noun(q{synaesthesia})->is_singular  => q{is_singular: 'synaesthesia'};
ok noun(q{agrogorod})->is_singular  => q{is_singular: 'agrogorod'};
ok noun(q{heroum})->is_singular  => q{is_singular: 'heroum'};
ok noun(q{stylus})->is_singular  => q{is_singular: 'stylus'};
ok noun(q{snooze})->is_singular  => q{is_singular: 'snooze'};
ok noun(q{starets})->is_singular  => q{is_singular: 'starets'};
ok noun(q{ellipse})->is_singular  => q{is_singular: 'ellipse'};
ok noun(q{cumulus})->is_singular  => q{is_singular: 'cumulus'};
ok noun(q{cicatrix})->is_singular  => q{is_singular: 'cicatrix'};
ok noun(q{scarus})->is_singular  => q{is_singular: 'scarus'};
ok noun(q{theologoumenon})->is_singular  => q{is_singular: 'theologoumenon'};
ok noun(q{exanthema})->is_singular  => q{is_singular: 'exanthema'};
ok noun(q{glacis})->is_singular  => q{is_singular: 'glacis'};
ok noun(q{clippers})->is_singular  => q{is_singular: 'clippers'};
ok noun(q{herring})->is_singular  => q{is_singular: 'herring'};
ok noun(q{residuum})->is_singular  => q{is_singular: 'residuum'};
ok noun(q{stalactite})->is_singular  => q{is_singular: 'stalactite'};
ok noun(q{sacrarium})->is_singular  => q{is_singular: 'sacrarium'};
ok noun(q{vehiculum})->is_singular  => q{is_singular: 'vehiculum'};
ok noun(q{quaesitum})->is_singular  => q{is_singular: 'quaesitum'};
ok noun(q{man child})->is_singular  => q{is_singular: 'man child'};
ok noun(q{Aragonese})->is_singular  => q{is_singular: 'Aragonese'};
ok noun(q{lamina})->is_singular  => q{is_singular: 'lamina'};
ok noun(q{motoscafo})->is_singular  => q{is_singular: 'motoscafo'};
ok noun(q{phren})->is_singular  => q{is_singular: 'phren'};
ok noun(q{rhinoceros})->is_singular  => q{is_singular: 'rhinoceros'};
ok noun(q{naumachia})->is_singular  => q{is_singular: 'naumachia'};
ok noun(q{simia})->is_singular  => q{is_singular: 'simia'};
ok noun(q{synaxarium})->is_singular  => q{is_singular: 'synaxarium'};
ok noun(q{kibbutz})->is_singular  => q{is_singular: 'kibbutz'};
ok noun(q{tegmentum})->is_singular  => q{is_singular: 'tegmentum'};
ok noun(q{stylopodium})->is_singular  => q{is_singular: 'stylopodium'};
ok noun(q{loa})->is_singular  => q{is_singular: 'loa'};
ok noun(q{quinarius})->is_singular  => q{is_singular: 'quinarius'};
ok noun(q{zitella})->is_singular  => q{is_singular: 'zitella'};
ok noun(q{elf})->is_singular  => q{is_singular: 'elf'};
ok noun(q{sericterium})->is_singular  => q{is_singular: 'sericterium'};
ok noun(q{Ningbo})->is_singular  => q{is_singular: 'Ningbo'};
ok noun(q{fedai})->is_singular  => q{is_singular: 'fedai'};
ok noun(q{protarsus})->is_singular  => q{is_singular: 'protarsus'};
ok noun(q{allegro})->is_singular  => q{is_singular: 'allegro'};
ok noun(q{vertebra})->is_singular  => q{is_singular: 'vertebra'};
ok noun(q{sciolus})->is_singular  => q{is_singular: 'sciolus'};
ok noun(q{salivarium})->is_singular  => q{is_singular: 'salivarium'};
ok noun(q{paraganglioma})->is_singular  => q{is_singular: 'paraganglioma'};
ok noun(q{Pardusco})->is_singular  => q{is_singular: 'Pardusco'};
ok noun(q{calathus})->is_singular  => q{is_singular: 'calathus'};
ok noun(q{Malabarese})->is_singular  => q{is_singular: 'Malabarese'};
ok noun(q{mesothelium})->is_singular  => q{is_singular: 'mesothelium'};
ok noun(q{zizz})->is_singular  => q{is_singular: 'zizz'};
ok noun(q{diplococcus})->is_singular  => q{is_singular: 'diplococcus'};
ok noun(q{meatus})->is_singular  => q{is_singular: 'meatus'};
ok noun(q{talouse})->is_singular  => q{is_singular: 'talouse'};
ok noun(q{1-star general})->is_singular  => q{is_singular: '1-star general'};
ok noun(q{vagus})->is_singular  => q{is_singular: 'vagus'};
ok noun(q{pedicellaria})->is_singular  => q{is_singular: 'pedicellaria'};
ok noun(q{pseudopodium})->is_singular  => q{is_singular: 'pseudopodium'};
ok noun(q{yo yo})->is_singular  => q{is_singular: 'yo yo'};
ok noun(q{logo})->is_singular  => q{is_singular: 'logo'};
ok noun(q{ipse dixit})->is_singular  => q{is_singular: 'ipse dixit'};
ok noun(q{acropolis})->is_singular  => q{is_singular: 'acropolis'};
ok noun(q{uomo universale})->is_singular  => q{is_singular: 'uomo universale'};
ok noun(q{casus belli})->is_singular  => q{is_singular: 'casus belli'};
ok noun(q{jerry})->is_singular  => q{is_singular: 'jerry'};
ok noun(q{summum bonum})->is_singular  => q{is_singular: 'summum bonum'};
ok noun(q{denarius})->is_singular  => q{is_singular: 'denarius'};
ok noun(q{terrae filius})->is_singular  => q{is_singular: 'terrae filius'};
ok noun(q{metropolis})->is_singular  => q{is_singular: 'metropolis'};
ok noun(q{itself})->is_singular  => q{is_singular: 'itself'};
ok noun(q{chateau})->is_singular  => q{is_singular: 'chateau'};
ok noun(q{furioso})->is_singular  => q{is_singular: 'furioso'};
ok noun(q{maximum})->is_singular  => q{is_singular: 'maximum'};
ok noun(q{pingo})->is_singular  => q{is_singular: 'pingo'};
ok noun(q{alguacil})->is_singular  => q{is_singular: 'alguacil'};
ok noun(q{aculeus})->is_singular  => q{is_singular: 'aculeus'};
ok noun(q{heroon})->is_singular  => q{is_singular: 'heroon'};
ok noun(q{Greensboro})->is_singular  => q{is_singular: 'Greensboro'};
ok noun(q{Lyonese})->is_singular  => q{is_singular: 'Lyonese'};
ok noun(q{Alfurese})->is_singular  => q{is_singular: 'Alfurese'};
ok noun(q{secans})->is_singular  => q{is_singular: 'secans'};
ok noun(q{desma})->is_singular  => q{is_singular: 'desma'};
ok noun(q{Sundanese})->is_singular  => q{is_singular: 'Sundanese'};
ok noun(q{washer-up})->is_singular  => q{is_singular: 'washer-up'};
ok noun(q{nodus})->is_singular  => q{is_singular: 'nodus'};
ok noun(q{filaria})->is_singular  => q{is_singular: 'filaria'};
ok noun(q{coma})->is_singular  => q{is_singular: 'coma'};
ok noun(q{protypon})->is_singular  => q{is_singular: 'protypon'};
ok noun(q{ploshchadka})->is_singular  => q{is_singular: 'ploshchadka'};
ok noun(q{she})->is_singular  => q{is_singular: 'she'};
ok noun(q{I})->is_singular  => q{is_singular: 'I'};
ok noun(q{moscardino})->is_singular  => q{is_singular: 'moscardino'};
ok noun(q{alias})->is_singular  => q{is_singular: 'alias'};
ok noun(q{mare})->is_singular  => q{is_singular: 'mare'};
ok noun(q{avocado})->is_singular  => q{is_singular: 'avocado'};
ok noun(q{sago})->is_singular  => q{is_singular: 'sago'};
ok noun(q{fioritura})->is_singular  => q{is_singular: 'fioritura'};
ok noun(q{port de bras})->is_singular  => q{is_singular: 'port de bras'};
ok noun(q{fidei defensor})->is_singular  => q{is_singular: 'fidei defensor'};
ok noun(q{livedo})->is_singular  => q{is_singular: 'livedo'};
ok noun(q{Annamese})->is_singular  => q{is_singular: 'Annamese'};
ok noun(q{epididymis})->is_singular  => q{is_singular: 'epididymis'};
ok noun(q{molimen})->is_singular  => q{is_singular: 'molimen'};
ok noun(q{portico})->is_singular  => q{is_singular: 'portico'};
ok noun(q{lux})->is_singular  => q{is_singular: 'lux'};
ok noun(q{mine})->is_singular  => q{is_singular: 'mine'};
ok noun(q{pneumothorax})->is_singular  => q{is_singular: 'pneumothorax'};
ok noun(q{syncellus})->is_singular  => q{is_singular: 'syncellus'};
ok noun(q{pleura})->is_singular  => q{is_singular: 'pleura'};
ok noun(q{coz})->is_singular  => q{is_singular: 'coz'};
ok noun(q{bilbo})->is_singular  => q{is_singular: 'bilbo'};
ok noun(q{sambo})->is_singular  => q{is_singular: 'sambo'};
ok noun(q{perithecium})->is_singular  => q{is_singular: 'perithecium'};
ok noun(q{Macanese})->is_singular  => q{is_singular: 'Macanese'};
ok noun(q{stephanion})->is_singular  => q{is_singular: 'stephanion'};
ok noun(q{generalissimo})->is_singular  => q{is_singular: 'generalissimo'};
ok noun(q{loaf})->is_singular  => q{is_singular: 'loaf'};
ok noun(q{fabella})->is_singular  => q{is_singular: 'fabella'};
ok noun(q{phenomenon})->is_singular  => q{is_singular: 'phenomenon'};
ok noun(q{man-servant})->is_singular  => q{is_singular: 'man-servant'};
ok noun(q{honorarium})->is_singular  => q{is_singular: 'honorarium'};
ok noun(q{paries})->is_singular  => q{is_singular: 'paries'};
ok noun(q{guglio})->is_singular  => q{is_singular: 'guglio'};
ok noun(q{mezuzah})->is_singular  => q{is_singular: 'mezuzah'};
ok noun(q{designatum})->is_singular  => q{is_singular: 'designatum'};
ok noun(q{brother german})->is_singular  => q{is_singular: 'brother german'};
ok noun(q{amentum})->is_singular  => q{is_singular: 'amentum'};
ok noun(q{gumma})->is_singular  => q{is_singular: 'gumma'};
ok noun(q{ruse de guerre})->is_singular  => q{is_singular: 'ruse de guerre'};
ok noun(q{pleuron})->is_singular  => q{is_singular: 'pleuron'};
ok noun(q{diastema})->is_singular  => q{is_singular: 'diastema'};
ok noun(q{ranunculus})->is_singular  => q{is_singular: 'ranunculus'};
ok noun(q{nauplius})->is_singular  => q{is_singular: 'nauplius'};
ok noun(q{neuma})->is_singular  => q{is_singular: 'neuma'};
ok noun(q{tarantato})->is_singular  => q{is_singular: 'tarantato'};
ok noun(q{hinaki})->is_singular  => q{is_singular: 'hinaki'};
ok noun(q{pincer})->is_singular  => q{is_singular: 'pincer'};
ok noun(q{monorchis})->is_singular  => q{is_singular: 'monorchis'};
ok noun(q{osculum})->is_singular  => q{is_singular: 'osculum'};
ok noun(q{fungus})->is_singular  => q{is_singular: 'fungus'};
ok noun(q{Tyrolese})->is_singular  => q{is_singular: 'Tyrolese'};
ok noun(q{diabetes})->is_singular  => q{is_singular: 'diabetes'};
ok noun(q{monstre sacre})->is_singular  => q{is_singular: 'monstre sacre'};
ok noun(q{scolopidium})->is_singular  => q{is_singular: 'scolopidium'};
ok noun(q{Singhalese})->is_singular  => q{is_singular: 'Singhalese'};
ok noun(q{concetto})->is_singular  => q{is_singular: 'concetto'};
ok noun(q{caddis})->is_singular  => q{is_singular: 'caddis'};
ok noun(q{germarium})->is_singular  => q{is_singular: 'germarium'};
ok noun(q{Sogdianese})->is_singular  => q{is_singular: 'Sogdianese'};
ok noun(q{glass})->is_singular  => q{is_singular: 'glass'};
ok noun(q{plasmalemma})->is_singular  => q{is_singular: 'plasmalemma'};
ok noun(q{porcino})->is_singular  => q{is_singular: 'porcino'};
ok noun(q{pala})->is_singular  => q{is_singular: 'pala'};
ok noun(q{metatarsus})->is_singular  => q{is_singular: 'metatarsus'};
ok noun(q{index})->is_singular  => q{is_singular: 'index'};
ok noun(q{scudo})->is_singular  => q{is_singular: 'scudo'};
ok noun(q{pedion})->is_singular  => q{is_singular: 'pedion'};
ok noun(q{larynx})->is_singular  => q{is_singular: 'larynx'};
ok noun(q{scuola})->is_singular  => q{is_singular: 'scuola'};
ok noun(q{bursch})->is_singular  => q{is_singular: 'bursch'};
ok noun(q{suggestio falsi})->is_singular  => q{is_singular: 'suggestio falsi'};
ok noun(q{fabliau})->is_singular  => q{is_singular: 'fabliau'};
ok noun(q{interaxis})->is_singular  => q{is_singular: 'interaxis'};
ok noun(q{Andamanese})->is_singular  => q{is_singular: 'Andamanese'};
ok noun(q{zadruga})->is_singular  => q{is_singular: 'zadruga'};
ok noun(q{limo})->is_singular  => q{is_singular: 'limo'};
ok noun(q{pomme de terre})->is_singular  => q{is_singular: 'pomme de terre'};
ok noun(q{yarraman})->is_singular  => q{is_singular: 'yarraman'};
ok noun(q{nymphaeum})->is_singular  => q{is_singular: 'nymphaeum'};
ok noun(q{propylon})->is_singular  => q{is_singular: 'propylon'};
ok noun(q{triforium})->is_singular  => q{is_singular: 'triforium'};
ok noun(q{woman child})->is_singular  => q{is_singular: 'woman child'};
ok noun(q{aide-de-camp})->is_singular  => q{is_singular: 'aide-de-camp'};
ok noun(q{tremolo})->is_singular  => q{is_singular: 'tremolo'};
ok noun(q{Avignonese})->is_singular  => q{is_singular: 'Avignonese'};
ok noun(q{soralium})->is_singular  => q{is_singular: 'soralium'};
ok noun(q{penny})->is_singular  => q{is_singular: 'penny'};
ok noun(q{rondo})->is_singular  => q{is_singular: 'rondo'};
ok noun(q{planula})->is_singular  => q{is_singular: 'planula'};
ok noun(q{interregnum})->is_singular  => q{is_singular: 'interregnum'};
ok noun(q{kioko})->is_singular  => q{is_singular: 'kioko'};
ok noun(q{hernia})->is_singular  => q{is_singular: 'hernia'};
ok noun(q{haddock})->is_singular  => q{is_singular: 'haddock'};
ok noun(q{Lorrainese})->is_singular  => q{is_singular: 'Lorrainese'};
ok noun(q{pietra})->is_singular  => q{is_singular: 'pietra'};
ok noun(q{vlakte})->is_singular  => q{is_singular: 'vlakte'};
ok noun(q{wady})->is_singular  => q{is_singular: 'wady'};
ok noun(q{paranucleus})->is_singular  => q{is_singular: 'paranucleus'};
ok noun(q{frenum})->is_singular  => q{is_singular: 'frenum'};
ok noun(q{Norman})->is_singular  => q{is_singular: 'Norman'};
ok noun(q{silenus})->is_singular  => q{is_singular: 'silenus'};
ok noun(q{chromonema})->is_singular  => q{is_singular: 'chromonema'};
ok noun(q{ispravnik})->is_singular  => q{is_singular: 'ispravnik'};
ok noun(q{contadino})->is_singular  => q{is_singular: 'contadino'};
ok noun(q{osteoma})->is_singular  => q{is_singular: 'osteoma'};
ok noun(q{kantharos})->is_singular  => q{is_singular: 'kantharos'};
ok noun(q{proseucha})->is_singular  => q{is_singular: 'proseucha'};
ok noun(q{Barquisimeto})->is_singular  => q{is_singular: 'Barquisimeto'};
ok noun(q{caffe ristretto})->is_singular  => q{is_singular: 'caffe ristretto'};
ok noun(q{set-to})->is_singular  => q{is_singular: 'set-to'};
ok noun(q{gluteus})->is_singular  => q{is_singular: 'gluteus'};
ok noun(q{scyphus})->is_singular  => q{is_singular: 'scyphus'};
ok noun(q{mezzo-rilievo})->is_singular  => q{is_singular: 'mezzo-rilievo'};
ok noun(q{teratoma})->is_singular  => q{is_singular: 'teratoma'};
ok noun(q{fasciculus})->is_singular  => q{is_singular: 'fasciculus'};
ok noun(q{thraso})->is_singular  => q{is_singular: 'thraso'};
ok noun(q{scotoma})->is_singular  => q{is_singular: 'scotoma'};
ok noun(q{epilimnion})->is_singular  => q{is_singular: 'epilimnion'};
ok noun(q{genie})->is_singular  => q{is_singular: 'genie'};
ok noun(q{responsum})->is_singular  => q{is_singular: 'responsum'};
ok noun(q{arcosolium})->is_singular  => q{is_singular: 'arcosolium'};
ok noun(q{likuta})->is_singular  => q{is_singular: 'likuta'};
ok noun(q{Cassinese})->is_singular  => q{is_singular: 'Cassinese'};
ok noun(q{falx})->is_singular  => q{is_singular: 'falx'};
ok noun(q{intervallum})->is_singular  => q{is_singular: 'intervallum'};
ok noun(q{plica})->is_singular  => q{is_singular: 'plica'};
ok noun(q{programma})->is_singular  => q{is_singular: 'programma'};
ok noun(q{franc-archer})->is_singular  => q{is_singular: 'franc-archer'};
ok noun(q{bel-esprit})->is_singular  => q{is_singular: 'bel-esprit'};
ok noun(q{varix})->is_singular  => q{is_singular: 'varix'};
ok noun(q{regma})->is_singular  => q{is_singular: 'regma'};
ok noun(q{ballista})->is_singular  => q{is_singular: 'ballista'};
ok noun(q{contretemps})->is_singular  => q{is_singular: 'contretemps'};
ok noun(q{Gestapo})->is_singular  => q{is_singular: 'Gestapo'};
ok noun(q{batz})->is_singular  => q{is_singular: 'batz'};
ok noun(q{money})->is_singular  => q{is_singular: 'money'};
ok noun(q{hippocampus})->is_singular  => q{is_singular: 'hippocampus'};
ok noun(q{pueblo})->is_singular  => q{is_singular: 'pueblo'};
ok noun(q{condo})->is_singular  => q{is_singular: 'condo'};
ok noun(q{aficionado})->is_singular  => q{is_singular: 'aficionado'};
ok noun(q{abortorium})->is_singular  => q{is_singular: 'abortorium'};
ok noun(q{zucchini})->is_singular  => q{is_singular: 'zucchini'};
ok noun(q{niello})->is_singular  => q{is_singular: 'niello'};
ok noun(q{faveolus})->is_singular  => q{is_singular: 'faveolus'};
ok noun(q{villanella})->is_singular  => q{is_singular: 'villanella'};
ok noun(q{ala})->is_singular  => q{is_singular: 'ala'};
ok noun(q{ramulus})->is_singular  => q{is_singular: 'ramulus'};
ok noun(q{giuncus})->is_singular  => q{is_singular: 'giuncus'};
ok noun(q{stoma})->is_singular  => q{is_singular: 'stoma'};
ok noun(q{septenarius})->is_singular  => q{is_singular: 'septenarius'};
ok noun(q{microcephalus})->is_singular  => q{is_singular: 'microcephalus'};
ok noun(q{intaglio})->is_singular  => q{is_singular: 'intaglio'};
ok noun(q{retinaculum})->is_singular  => q{is_singular: 'retinaculum'};
ok noun(q{tour de force})->is_singular  => q{is_singular: 'tour de force'};
ok noun(q{panorpa})->is_singular  => q{is_singular: 'panorpa'};
ok noun(q{Cantonese})->is_singular  => q{is_singular: 'Cantonese'};
ok noun(q{viale})->is_singular  => q{is_singular: 'viale'};
ok noun(q{soprano})->is_singular  => q{is_singular: 'soprano'};
ok noun(q{postulatum})->is_singular  => q{is_singular: 'postulatum'};
ok noun(q{series})->is_singular  => q{is_singular: 'series'};
ok noun(q{rite de passage})->is_singular  => q{is_singular: 'rite de passage'};
ok noun(q{tango})->is_singular  => q{is_singular: 'tango'};
ok noun(q{equinoctium})->is_singular  => q{is_singular: 'equinoctium'};
ok noun(q{rejon})->is_singular  => q{is_singular: 'rejon'};
ok noun(q{stroma})->is_singular  => q{is_singular: 'stroma'};
ok noun(q{usnea})->is_singular  => q{is_singular: 'usnea'};
ok noun(q{leptospira})->is_singular  => q{is_singular: 'leptospira'};
ok noun(q{louse})->is_singular  => q{is_singular: 'louse'};
ok noun(q{legionella})->is_singular  => q{is_singular: 'legionella'};
ok noun(q{epiphenomenon})->is_singular  => q{is_singular: 'epiphenomenon'};
ok noun(q{tempietto})->is_singular  => q{is_singular: 'tempietto'};
ok noun(q{septum})->is_singular  => q{is_singular: 'septum'};
ok noun(q{follis})->is_singular  => q{is_singular: 'follis'};
ok noun(q{4 star general})->is_singular  => q{is_singular: '4 star general'};
ok noun(q{logodaedalus})->is_singular  => q{is_singular: 'logodaedalus'};
ok noun(q{phalanx})->is_singular  => q{is_singular: 'phalanx'};
ok noun(q{menage a trois})->is_singular  => q{is_singular: 'menage a trois'};
ok noun(q{staphylococcus})->is_singular  => q{is_singular: 'staphylococcus'};
ok noun(q{locus})->is_singular  => q{is_singular: 'locus'};
ok noun(q{simpulum})->is_singular  => q{is_singular: 'simpulum'};
ok noun(q{mustachio})->is_singular  => q{is_singular: 'mustachio'};
ok noun(q{edema})->is_singular  => q{is_singular: 'edema'};
ok noun(q{enteron})->is_singular  => q{is_singular: 'enteron'};
ok noun(q{symplasma})->is_singular  => q{is_singular: 'symplasma'};
ok noun(q{marquis})->is_singular  => q{is_singular: 'marquis'};
ok noun(q{noctiluca})->is_singular  => q{is_singular: 'noctiluca'};
ok noun(q{stimulus})->is_singular  => q{is_singular: 'stimulus'};
ok noun(q{ruga})->is_singular  => q{is_singular: 'ruga'};
ok noun(q{res})->is_singular  => q{is_singular: 'res'};
ok noun(q{alveolus})->is_singular  => q{is_singular: 'alveolus'};
ok noun(q{profluvium})->is_singular  => q{is_singular: 'profluvium'};
ok noun(q{Majuro})->is_singular  => q{is_singular: 'Majuro'};
ok noun(q{glochidium})->is_singular  => q{is_singular: 'glochidium'};
ok noun(q{verticillus})->is_singular  => q{is_singular: 'verticillus'};
ok noun(q{seecatch})->is_singular  => q{is_singular: 'seecatch'};
ok noun(q{Esperanto})->is_singular  => q{is_singular: 'Esperanto'};
ok noun(q{urus})->is_singular  => q{is_singular: 'urus'};
ok noun(q{penis})->is_singular  => q{is_singular: 'penis'};
ok noun(q{indicium})->is_singular  => q{is_singular: 'indicium'};
ok noun(q{bregma})->is_singular  => q{is_singular: 'bregma'};
ok noun(q{waldo})->is_singular  => q{is_singular: 'waldo'};
ok noun(q{woman servant})->is_singular  => q{is_singular: 'woman servant'};
ok noun(q{helix})->is_singular  => q{is_singular: 'helix'};
ok noun(q{suppositum})->is_singular  => q{is_singular: 'suppositum'};
ok noun(q{osteoclastoma})->is_singular  => q{is_singular: 'osteoclastoma'};
ok noun(q{phyllobranchia})->is_singular  => q{is_singular: 'phyllobranchia'};
ok noun(q{sterigma})->is_singular  => q{is_singular: 'sterigma'};
ok noun(q{Purum})->is_singular  => q{is_singular: 'Purum'};
ok noun(q{verso})->is_singular  => q{is_singular: 'verso'};
ok noun(q{acarus})->is_singular  => q{is_singular: 'acarus'};
ok noun(q{scolex})->is_singular  => q{is_singular: 'scolex'};
ok noun(q{indusium})->is_singular  => q{is_singular: 'indusium'};
ok noun(q{man-child})->is_singular  => q{is_singular: 'man-child'};
ok noun(q{calamistrum})->is_singular  => q{is_singular: 'calamistrum'};
ok noun(q{parador})->is_singular  => q{is_singular: 'parador'};
ok noun(q{melastoma})->is_singular  => q{is_singular: 'melastoma'};
ok noun(q{trousers})->is_singular  => q{is_singular: 'trousers'};
ok noun(q{octohedron})->is_singular  => q{is_singular: 'octohedron'};
ok noun(q{whosever})->is_singular  => q{is_singular: 'whosever'};
ok noun(q{minutia})->is_singular  => q{is_singular: 'minutia'};
ok noun(q{inoculum})->is_singular  => q{is_singular: 'inoculum'};
ok noun(q{torma})->is_singular  => q{is_singular: 'torma'};
ok noun(q{ragazza})->is_singular  => q{is_singular: 'ragazza'};
ok noun(q{termes})->is_singular  => q{is_singular: 'termes'};
ok noun(q{nectocalyx})->is_singular  => q{is_singular: 'nectocalyx'};
ok noun(q{Draco})->is_singular  => q{is_singular: 'Draco'};
ok noun(q{pilus})->is_singular  => q{is_singular: 'pilus'};
ok noun(q{nucleus})->is_singular  => q{is_singular: 'nucleus'};
ok noun(q{tazza})->is_singular  => q{is_singular: 'tazza'};
ok noun(q{metapleuron})->is_singular  => q{is_singular: 'metapleuron'};
ok noun(q{aggro})->is_singular  => q{is_singular: 'aggro'};
ok noun(q{halteridium})->is_singular  => q{is_singular: 'halteridium'};
ok noun(q{octopus})->is_singular  => q{is_singular: 'octopus'};
ok noun(q{Japanese})->is_singular  => q{is_singular: 'Japanese'};
ok noun(q{paxilla})->is_singular  => q{is_singular: 'paxilla'};
ok noun(q{thymus})->is_singular  => q{is_singular: 'thymus'};
ok noun(q{proferens})->is_singular  => q{is_singular: 'proferens'};
ok noun(q{Chicago})->is_singular  => q{is_singular: 'Chicago'};
ok noun(q{trellis})->is_singular  => q{is_singular: 'trellis'};
ok noun(q{fowl})->is_singular  => q{is_singular: 'fowl'};
ok noun(q{frate})->is_singular  => q{is_singular: 'frate'};
ok noun(q{aptychus})->is_singular  => q{is_singular: 'aptychus'};
ok noun(q{progymnasium})->is_singular  => q{is_singular: 'progymnasium'};
ok noun(q{Jerry})->is_singular  => q{is_singular: 'Jerry'};
ok noun(q{cello})->is_singular  => q{is_singular: 'cello'};
ok noun(q{mews})->is_singular  => q{is_singular: 'mews'};
ok noun(q{Vietnamese})->is_singular  => q{is_singular: 'Vietnamese'};
ok noun(q{tenuis})->is_singular  => q{is_singular: 'tenuis'};
ok noun(q{Antananarivo})->is_singular  => q{is_singular: 'Antananarivo'};
ok noun(q{referendum})->is_singular  => q{is_singular: 'referendum'};
ok noun(q{hippo})->is_singular  => q{is_singular: 'hippo'};
ok noun(q{syringe})->is_singular  => q{is_singular: 'syringe'};
ok noun(q{starfish})->is_singular  => q{is_singular: 'starfish'};
ok noun(q{mary})->is_singular  => q{is_singular: 'mary'};
ok noun(q{quantum})->is_singular  => q{is_singular: 'quantum'};
ok noun(q{ditto})->is_singular  => q{is_singular: 'ditto'};
ok noun(q{pleco})->is_singular  => q{is_singular: 'pleco'};
ok noun(q{magnifico})->is_singular  => q{is_singular: 'magnifico'};
ok noun(q{hypha})->is_singular  => q{is_singular: 'hypha'};
ok noun(q{podetium})->is_singular  => q{is_singular: 'podetium'};
ok noun(q{prosa})->is_singular  => q{is_singular: 'prosa'};
ok noun(q{secundigravida})->is_singular  => q{is_singular: 'secundigravida'};
ok noun(q{chapplis})->is_singular  => q{is_singular: 'chapplis'};
ok noun(q{Pangasinan})->is_singular  => q{is_singular: 'Pangasinan'};
ok noun(q{coxendix})->is_singular  => q{is_singular: 'coxendix'};
ok noun(q{man-midwife})->is_singular  => q{is_singular: 'man-midwife'};
ok noun(q{tetrahedron})->is_singular  => q{is_singular: 'tetrahedron'};
ok noun(q{chrysalis})->is_singular  => q{is_singular: 'chrysalis'};
ok noun(q{agend})->is_singular  => q{is_singular: 'agend'};
ok noun(q{strategos})->is_singular  => q{is_singular: 'strategos'};
ok noun(q{entrochus})->is_singular  => q{is_singular: 'entrochus'};
ok noun(q{trabea})->is_singular  => q{is_singular: 'trabea'};
ok noun(q{nuntius})->is_singular  => q{is_singular: 'nuntius'};
ok noun(q{parc ferme})->is_singular  => q{is_singular: 'parc ferme'};
ok noun(q{taenia})->is_singular  => q{is_singular: 'taenia'};
ok noun(q{scazon})->is_singular  => q{is_singular: 'scazon'};
ok noun(q{maestro})->is_singular  => q{is_singular: 'maestro'};
ok noun(q{buffalo})->is_singular  => q{is_singular: 'buffalo'};
ok noun(q{lf})->is_singular  => q{is_singular: 'lf'};
ok noun(q{Quito})->is_singular  => q{is_singular: 'Quito'};
ok noun(q{remex})->is_singular  => q{is_singular: 'remex'};
ok noun(q{stromodeum})->is_singular  => q{is_singular: 'stromodeum'};
ok noun(q{shauri})->is_singular  => q{is_singular: 'shauri'};
ok noun(q{wharf})->is_singular  => q{is_singular: 'wharf'};
ok noun(q{belle epoque})->is_singular  => q{is_singular: 'belle epoque'};
ok noun(q{nympha})->is_singular  => q{is_singular: 'nympha'};
ok noun(q{striga})->is_singular  => q{is_singular: 'striga'};
ok noun(q{Hararese})->is_singular  => q{is_singular: 'Hararese'};
ok noun(q{six-star general})->is_singular  => q{is_singular: 'six-star general'};
ok noun(q{bimbo})->is_singular  => q{is_singular: 'bimbo'};
ok noun(q{flamenco})->is_singular  => q{is_singular: 'flamenco'};
ok noun(q{Morocco})->is_singular  => q{is_singular: 'Morocco'};
ok noun(q{fuzz})->is_singular  => q{is_singular: 'fuzz'};
ok noun(q{mater lectionis})->is_singular  => q{is_singular: 'mater lectionis'};
ok noun(q{Yokohaman})->is_singular  => q{is_singular: 'Yokohaman'};
ok noun(q{serum})->is_singular  => q{is_singular: 'serum'};
ok noun(q{fibroma})->is_singular  => q{is_singular: 'fibroma'};
ok noun(q{vinculum})->is_singular  => q{is_singular: 'vinculum'};
ok noun(q{pensiero})->is_singular  => q{is_singular: 'pensiero'};
ok noun(q{felo-de-se})->is_singular  => q{is_singular: 'felo-de-se'};
ok noun(q{faciendum})->is_singular  => q{is_singular: 'faciendum'};
ok noun(q{white staff})->is_singular  => q{is_singular: 'white staff'};
ok noun(q{Nakayaman})->is_singular  => q{is_singular: 'Nakayaman'};
ok noun(q{interambulacrum})->is_singular  => q{is_singular: 'interambulacrum'};
ok noun(q{synaxis})->is_singular  => q{is_singular: 'synaxis'};
ok noun(q{tenaculum})->is_singular  => q{is_singular: 'tenaculum'};
ok noun(q{biscotto})->is_singular  => q{is_singular: 'biscotto'};
ok noun(q{caryopsis})->is_singular  => q{is_singular: 'caryopsis'};
ok noun(q{Modenese})->is_singular  => q{is_singular: 'Modenese'};
ok noun(q{simulacrum})->is_singular  => q{is_singular: 'simulacrum'};
ok noun(q{proboscis})->is_singular  => q{is_singular: 'proboscis'};
ok noun(q{statua})->is_singular  => q{is_singular: 'statua'};
ok noun(q{cardophagus})->is_singular  => q{is_singular: 'cardophagus'};
ok noun(q{macho})->is_singular  => q{is_singular: 'macho'};
ok noun(q{virus})->is_singular  => q{is_singular: 'virus'};
ok noun(q{pyramidion})->is_singular  => q{is_singular: 'pyramidion'};
ok noun(q{nenets})->is_singular  => q{is_singular: 'nenets'};
ok noun(q{Timorese})->is_singular  => q{is_singular: 'Timorese'};
ok noun(q{shears})->is_singular  => q{is_singular: 'shears'};
ok noun(q{rostrum})->is_singular  => q{is_singular: 'rostrum'};
ok noun(q{cosmos})->is_singular  => q{is_singular: 'cosmos'};
ok noun(q{collegium musicum})->is_singular  => q{is_singular: 'collegium musicum'};
ok noun(q{3 star general})->is_singular  => q{is_singular: '3 star general'};
ok noun(q{dynamo})->is_singular  => q{is_singular: 'dynamo'};
ok noun(q{muzz})->is_singular  => q{is_singular: 'muzz'};
ok noun(q{vers libre})->is_singular  => q{is_singular: 'vers libre'};
ok noun(q{bronchus})->is_singular  => q{is_singular: 'bronchus'};
ok noun(q{her})->is_singular  => q{is_singular: 'her'};
ok noun(q{concertino})->is_singular  => q{is_singular: 'concertino'};
ok noun(q{loma})->is_singular  => q{is_singular: 'loma'};
ok noun(q{bel homme})->is_singular  => q{is_singular: 'bel homme'};
ok noun(q{stabilimentum})->is_singular  => q{is_singular: 'stabilimentum'};
ok noun(q{Iquico})->is_singular  => q{is_singular: 'Iquico'};
ok noun(q{hertz})->is_singular  => q{is_singular: 'hertz'};
ok noun(q{epicardium})->is_singular  => q{is_singular: 'epicardium'};
ok noun(q{cochito})->is_singular  => q{is_singular: 'cochito'};
ok noun(q{tegula})->is_singular  => q{is_singular: 'tegula'};
ok noun(q{oxybaphon})->is_singular  => q{is_singular: 'oxybaphon'};
ok noun(q{anacoluthon})->is_singular  => q{is_singular: 'anacoluthon'};
ok noun(q{hapax legomenon})->is_singular  => q{is_singular: 'hapax legomenon'};
ok noun(q{oedema})->is_singular  => q{is_singular: 'oedema'};
ok noun(q{ignoramus})->is_singular  => q{is_singular: 'ignoramus'};
ok noun(q{sizz})->is_singular  => q{is_singular: 'sizz'};
ok noun(q{vivarium})->is_singular  => q{is_singular: 'vivarium'};
ok noun(q{secundipara})->is_singular  => q{is_singular: 'secundipara'};
ok noun(q{poblador})->is_singular  => q{is_singular: 'poblador'};
ok noun(q{brigadier general})->is_singular  => q{is_singular: 'brigadier general'};
ok noun(q{velum})->is_singular  => q{is_singular: 'velum'};
ok noun(q{succinea})->is_singular  => q{is_singular: 'succinea'};
ok noun(q{army-corps general})->is_singular  => q{is_singular: 'army-corps general'};
ok noun(q{pinto})->is_singular  => q{is_singular: 'pinto'};
ok noun(q{turron})->is_singular  => q{is_singular: 'turron'};
ok noun(q{papula})->is_singular  => q{is_singular: 'papula'};
ok noun(q{mediastinum})->is_singular  => q{is_singular: 'mediastinum'};
ok noun(q{bateau})->is_singular  => q{is_singular: 'bateau'};
ok noun(q{photo})->is_singular  => q{is_singular: 'photo'};
ok noun(q{Arakanese})->is_singular  => q{is_singular: 'Arakanese'};
ok noun(q{sol})->is_singular  => q{is_singular: 'sol'};
ok noun(q{sarcina})->is_singular  => q{is_singular: 'sarcina'};
ok noun(q{supernova})->is_singular  => q{is_singular: 'supernova'};
ok noun(q{intercalarium})->is_singular  => q{is_singular: 'intercalarium'};
ok noun(q{trousseau})->is_singular  => q{is_singular: 'trousseau'};
ok noun(q{zygoma})->is_singular  => q{is_singular: 'zygoma'};
ok noun(q{vetturino})->is_singular  => q{is_singular: 'vetturino'};
ok noun(q{depositum})->is_singular  => q{is_singular: 'depositum'};
ok noun(q{Mexico})->is_singular  => q{is_singular: 'Mexico'};
ok noun(q{modernus})->is_singular  => q{is_singular: 'modernus'};
ok noun(q{conductus})->is_singular  => q{is_singular: 'conductus'};
ok noun(q{flabellum})->is_singular  => q{is_singular: 'flabellum'};
ok noun(q{turf})->is_singular  => q{is_singular: 'turf'};
ok noun(q{seed})->is_singular  => q{is_singular: 'seed'};
ok noun(q{autobahn})->is_singular  => q{is_singular: 'autobahn'};
ok noun(q{vas})->is_singular  => q{is_singular: 'vas'};
ok noun(q{unguis})->is_singular  => q{is_singular: 'unguis'};
ok noun(q{extremum})->is_singular  => q{is_singular: 'extremum'};
ok noun(q{pluteus})->is_singular  => q{is_singular: 'pluteus'};
ok noun(q{tipula})->is_singular  => q{is_singular: 'tipula'};
ok noun(q{hetaira})->is_singular  => q{is_singular: 'hetaira'};
ok noun(q{zoosporangium})->is_singular  => q{is_singular: 'zoosporangium'};
ok noun(q{jalapeno})->is_singular  => q{is_singular: 'jalapeno'};
ok noun(q{that})->is_singular  => q{is_singular: 'that'};
ok noun(q{tractatrix})->is_singular  => q{is_singular: 'tractatrix'};
ok noun(q{lorum})->is_singular  => q{is_singular: 'lorum'};
ok noun(q{Polonese})->is_singular  => q{is_singular: 'Polonese'};
ok noun(q{substratum})->is_singular  => q{is_singular: 'substratum'};
ok noun(q{utricularia})->is_singular  => q{is_singular: 'utricularia'};
ok noun(q{hemangioma})->is_singular  => q{is_singular: 'hemangioma'};
ok noun(q{rimon})->is_singular  => q{is_singular: 'rimon'};
ok noun(q{tholos})->is_singular  => q{is_singular: 'tholos'};
ok noun(q{Ferrarese})->is_singular  => q{is_singular: 'Ferrarese'};
ok noun(q{valvula})->is_singular  => q{is_singular: 'valvula'};
ok noun(q{Angolese})->is_singular  => q{is_singular: 'Angolese'};
ok noun(q{syrphus})->is_singular  => q{is_singular: 'syrphus'};
ok noun(q{Torino})->is_singular  => q{is_singular: 'Torino'};
ok noun(q{appressorium})->is_singular  => q{is_singular: 'appressorium'};
ok noun(q{tomato})->is_singular  => q{is_singular: 'tomato'};
ok noun(q{messa di voce})->is_singular  => q{is_singular: 'messa di voce'};
ok noun(q{colonel general})->is_singular  => q{is_singular: 'colonel general'};
ok noun(q{amphora})->is_singular  => q{is_singular: 'amphora'};
ok noun(q{nemathecium})->is_singular  => q{is_singular: 'nemathecium'};
ok noun(q{velamen})->is_singular  => q{is_singular: 'velamen'};
ok noun(q{louis})->is_singular  => q{is_singular: 'louis'};
ok noun(q{Bamako})->is_singular  => q{is_singular: 'Bamako'};
ok noun(q{prothallium})->is_singular  => q{is_singular: 'prothallium'};
ok noun(q{aureus})->is_singular  => q{is_singular: 'aureus'};
ok noun(q{heft})->is_singular  => q{is_singular: 'heft'};
ok noun(q{rotula})->is_singular  => q{is_singular: 'rotula'};
ok noun(q{timpano})->is_singular  => q{is_singular: 'timpano'};
ok noun(q{archipelago})->is_singular  => q{is_singular: 'archipelago'};
ok noun(q{rem})->is_singular  => q{is_singular: 'rem'};
ok noun(q{Milanese})->is_singular  => q{is_singular: 'Milanese'};
ok noun(q{terp})->is_singular  => q{is_singular: 'terp'};
ok noun(q{Messinese})->is_singular  => q{is_singular: 'Messinese'};
ok noun(q{blastema})->is_singular  => q{is_singular: 'blastema'};
ok noun(q{abortus})->is_singular  => q{is_singular: 'abortus'};
ok noun(q{cul de lampe})->is_singular  => q{is_singular: 'cul de lampe'};
ok noun(q{zuppa})->is_singular  => q{is_singular: 'zuppa'};
ok noun(q{fizz})->is_singular  => q{is_singular: 'fizz'};
ok noun(q{whom})->is_singular  => q{is_singular: 'whom'};
ok noun(q{arista})->is_singular  => q{is_singular: 'arista'};
ok noun(q{maxilla})->is_singular  => q{is_singular: 'maxilla'};
ok noun(q{beef})->is_singular  => q{is_singular: 'beef'};
ok noun(q{idolum})->is_singular  => q{is_singular: 'idolum'};
ok noun(q{agent provocateur})->is_singular  => q{is_singular: 'agent provocateur'};
ok noun(q{pragma})->is_singular  => q{is_singular: 'pragma'};
ok noun(q{iter})->is_singular  => q{is_singular: 'iter'};
ok noun(q{gyrus})->is_singular  => q{is_singular: 'gyrus'};
ok noun(q{hoti})->is_singular  => q{is_singular: 'hoti'};
ok noun(q{musee imaginaire})->is_singular  => q{is_singular: 'musee imaginaire'};
ok noun(q{summa})->is_singular  => q{is_singular: 'summa'};
ok noun(q{lomentum})->is_singular  => q{is_singular: 'lomentum'};
ok noun(q{vaginula})->is_singular  => q{is_singular: 'vaginula'};
ok noun(q{atlas})->is_singular  => q{is_singular: 'atlas'};
ok noun(q{agora})->is_singular  => q{is_singular: 'agora'};
ok noun(q{techno})->is_singular  => q{is_singular: 'techno'};
ok noun(q{rhino})->is_singular  => q{is_singular: 'rhino'};
ok noun(q{Otomi})->is_singular  => q{is_singular: 'Otomi'};
ok noun(q{glissando})->is_singular  => q{is_singular: 'glissando'};
ok noun(q{prosecutrix})->is_singular  => q{is_singular: 'prosecutrix'};
ok noun(q{Tenggerese})->is_singular  => q{is_singular: 'Tenggerese'};
ok noun(q{uncia})->is_singular  => q{is_singular: 'uncia'};
ok noun(q{diverticulum})->is_singular  => q{is_singular: 'diverticulum'};
ok noun(q{callus})->is_singular  => q{is_singular: 'callus'};
ok noun(q{Kosovo})->is_singular  => q{is_singular: 'Kosovo'};
ok noun(q{trapezius})->is_singular  => q{is_singular: 'trapezius'};
ok noun(q{parenchyma})->is_singular  => q{is_singular: 'parenchyma'};
ok noun(q{moaks})->is_singular  => q{is_singular: 'moaks'};
ok noun(q{tetragrammaton})->is_singular  => q{is_singular: 'tetragrammaton'};
ok noun(q{dreikanter})->is_singular  => q{is_singular: 'dreikanter'};
ok noun(q{pastorale})->is_singular  => q{is_singular: 'pastorale'};
ok noun(q{tetracolon})->is_singular  => q{is_singular: 'tetracolon'};
ok noun(q{schema})->is_singular  => q{is_singular: 'schema'};
ok noun(q{sedes})->is_singular  => q{is_singular: 'sedes'};
ok noun(q{finger-end})->is_singular  => q{is_singular: 'finger-end'};
ok noun(q{favella})->is_singular  => q{is_singular: 'favella'};
ok noun(q{eyas})->is_singular  => q{is_singular: 'eyas'};
ok noun(q{strobila})->is_singular  => q{is_singular: 'strobila'};
ok noun(q{interstitium})->is_singular  => q{is_singular: 'interstitium'};
ok noun(q{hymnarium})->is_singular  => q{is_singular: 'hymnarium'};
ok noun(q{fibula})->is_singular  => q{is_singular: 'fibula'};
ok noun(q{arboretum})->is_singular  => q{is_singular: 'arboretum'};
ok noun(q{monoxylon})->is_singular  => q{is_singular: 'monoxylon'};
ok noun(q{three-star general})->is_singular  => q{is_singular: 'three-star general'};
ok noun(q{one})->is_singular  => q{is_singular: 'one'};
ok noun(q{papyrus})->is_singular  => q{is_singular: 'papyrus'};
ok noun(q{thebe})->is_singular  => q{is_singular: 'thebe'};
ok noun(q{alluvium})->is_singular  => q{is_singular: 'alluvium'};
ok noun(q{Santiago})->is_singular  => q{is_singular: 'Santiago'};
ok noun(q{miasma})->is_singular  => q{is_singular: 'miasma'};
ok noun(q{ballata})->is_singular  => q{is_singular: 'ballata'};
ok noun(q{lixivium})->is_singular  => q{is_singular: 'lixivium'};
ok noun(q{praecognitum})->is_singular  => q{is_singular: 'praecognitum'};
ok noun(q{yuo})->is_singular  => q{is_singular: 'yuo'};
ok noun(q{veduta})->is_singular  => q{is_singular: 'veduta'};
ok noun(q{vitellarium})->is_singular  => q{is_singular: 'vitellarium'};
ok noun(q{hsien})->is_singular  => q{is_singular: 'hsien'};
ok noun(q{triplum})->is_singular  => q{is_singular: 'triplum'};
ok noun(q{venus})->is_singular  => q{is_singular: 'venus'};
ok noun(q{stria})->is_singular  => q{is_singular: 'stria'};
ok noun(q{Monaco})->is_singular  => q{is_singular: 'Monaco'};
ok noun(q{cuspis})->is_singular  => q{is_singular: 'cuspis'};
ok noun(q{pollinium})->is_singular  => q{is_singular: 'pollinium'};
ok noun(q{streptothrix})->is_singular  => q{is_singular: 'streptothrix'};
ok noun(q{sustentaculum})->is_singular  => q{is_singular: 'sustentaculum'};
ok noun(q{torus})->is_singular  => q{is_singular: 'torus'};
ok noun(q{nebenkern})->is_singular  => q{is_singular: 'nebenkern'};
ok noun(q{Azerbaijanese})->is_singular  => q{is_singular: 'Azerbaijanese'};
ok noun(q{set out})->is_singular  => q{is_singular: 'set out'};
ok noun(q{bubo})->is_singular  => q{is_singular: 'bubo'};
ok noun(q{fermata})->is_singular  => q{is_singular: 'fermata'};
ok noun(q{samurai})->is_singular  => q{is_singular: 'samurai'};
ok noun(q{salmon})->is_singular  => q{is_singular: 'salmon'};
ok noun(q{manchild})->is_singular  => q{is_singular: 'manchild'};
ok noun(q{libero})->is_singular  => q{is_singular: 'libero'};
ok noun(q{ricercata})->is_singular  => q{is_singular: 'ricercata'};
ok noun(q{leprosarium})->is_singular  => q{is_singular: 'leprosarium'};
ok noun(q{criterion})->is_singular  => q{is_singular: 'criterion'};
ok noun(q{lochus})->is_singular  => q{is_singular: 'lochus'};
ok noun(q{shad})->is_singular  => q{is_singular: 'shad'};
ok noun(q{sema})->is_singular  => q{is_singular: 'sema'};
ok noun(q{opus magnum})->is_singular  => q{is_singular: 'opus magnum'};
ok noun(q{pajamas})->is_singular  => q{is_singular: 'pajamas'};
ok noun(q{patera})->is_singular  => q{is_singular: 'patera'};
ok noun(q{talus})->is_singular  => q{is_singular: 'talus'};
ok noun(q{volcanello})->is_singular  => q{is_singular: 'volcanello'};
ok noun(q{stigma})->is_singular  => q{is_singular: 'stigma'};
ok noun(q{bodegon})->is_singular  => q{is_singular: 'bodegon'};
ok noun(q{hydraulicon})->is_singular  => q{is_singular: 'hydraulicon'};
ok noun(q{Spaetlese})->is_singular  => q{is_singular: 'Spaetlese'};
ok noun(q{pizza})->is_singular  => q{is_singular: 'pizza'};
ok noun(q{Nipponese})->is_singular  => q{is_singular: 'Nipponese'};
ok noun(q{plectrum})->is_singular  => q{is_singular: 'plectrum'};
ok noun(q{tenorino})->is_singular  => q{is_singular: 'tenorino'};
ok noun(q{aecidium})->is_singular  => q{is_singular: 'aecidium'};
ok noun(q{plethron})->is_singular  => q{is_singular: 'plethron'};
ok noun(q{tabula})->is_singular  => q{is_singular: 'tabula'};
ok noun(q{ambo})->is_singular  => q{is_singular: 'ambo'};
ok noun(q{fish})->is_singular  => q{is_singular: 'fish'};
ok noun(q{scherzando})->is_singular  => q{is_singular: 'scherzando'};
ok noun(q{saffo})->is_singular  => q{is_singular: 'saffo'};
ok noun(q{stipes})->is_singular  => q{is_singular: 'stipes'};
ok noun(q{sarissa})->is_singular  => q{is_singular: 'sarissa'};
ok noun(q{lord-lieutenant})->is_singular  => q{is_singular: 'lord-lieutenant'};
ok noun(q{souvlaki})->is_singular  => q{is_singular: 'souvlaki'};
ok noun(q{phoca})->is_singular  => q{is_singular: 'phoca'};
ok noun(q{lowlife})->is_singular  => q{is_singular: 'lowlife'};
ok noun(q{tessella})->is_singular  => q{is_singular: 'tessella'};
ok noun(q{Lesotho})->is_singular  => q{is_singular: 'Lesotho'};
ok noun(q{fascia})->is_singular  => q{is_singular: 'fascia'};

done_testing();
